@@ -1,11 +1,7 @@
 ;;; -------- auto-save 
 
-(use-modules (ice-9 format))
-
 (provide 'snd-autosave.scm)
 
-(if (not (provided? 'snd-extensions.scm)) (load-from-path "extensions.scm"))
-
 (define auto-save-interval 60.0) ;seconds between auto-save checks
 (define auto-saving #f)
 
