@@ -23,15 +23,14 @@
 ;;; out-scaler
 ;;;   scaler for the converted values
 
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-grani.scm)
 
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
-(if (not (provided? 'snd-env.scm)) (load-from-path "env.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
+(if (not (provided? 'snd-env.scm)) (load "env.scm"))
 
 (define grani-default-base (expt 2 (/ 12)))
 
-(define* (exp-envelope env :key
+(define* (exp-envelope env
 		       (base grani-default-base)
 		       (error 0.01)
 		       (scaler 1)
@@ -113,7 +112,7 @@
 ;;;  where:
 ;;;    vref=1.0 reference value = digital clipping
 
-(define* (db-envelope envelope :optional (cutoff -70) (error 0.01))
+(define* (db-envelope envelope (cutoff -70) (error 0.01))
   (exp-envelope envelope
 		:base 10
 		:scaler 1/20
@@ -121,7 +120,7 @@
 		:cutoff cutoff
 		:error error))
 
-(define* (make-db-env envelope :key
+(define* (make-db-env envelope
 		      (scaler 1)
 		      (offset 0)
 		      (base 1)
@@ -135,7 +134,7 @@
 
 ;;; Pitch envelopes (y units are semitone and octave intervals)
 
-(define* (semitones-envelope envelope :optional (around 1.0) (error 0.01))
+(define* (semitones-envelope envelope (around 1.0) (error 0.01))
   (exp-envelope envelope
 		:error error
 		:base (expt 2 (/ 12))
@@ -144,7 +143,7 @@
 		:offset 0
 		:out-scaler around))
 
-(define* (make-semitones-env envelope :key
+(define* (make-semitones-env envelope
 			     (around 1.0)
 			     (scaler 1.0)
 			     (offset 0.0)
@@ -156,7 +155,7 @@
 	    :scaler scaler :offset offset
 	    :base base :duration duration :length (+ 1 end)))
 
-(define* (octaves-envelope envelope :optional (around 1.0) (error 0.01))
+(define* (octaves-envelope envelope (around 1.0) (error 0.01))
   (exp-envelope envelope
 		:error error
 		:base 2
@@ -165,7 +164,7 @@
 		:offset 0
 		:out-scaler around))
 
-(define* (make-octaves-env envelope :key
+(define* (make-octaves-env envelope
 			   (around 1.0)
 			   (scaler 1.0)
 			   (offset 0.0)
@@ -231,7 +230,7 @@
 
 ;;; create a vct from an envelope
 
-(define* (make-gr-env env :optional (length 512))
+(define* (make-gr-env env (length 512))
   (let* ((env-vct (make-vct length))
 	 (length-1 (exact->inexact (- length 1))))
     (do ((i 0 (+ 1 i)))
@@ -241,7 +240,7 @@
 ;;;-----------------------------------------------------------------------------
 ;;; Grain envelopes
 
-(define* (raised-cosine :key 
+(define* (raised-cosine 
 			(duty-cycle 100)
 			(length 128))
   (let* ((v (make-vct length))
@@ -314,7 +313,7 @@
 (define grani-to-grain-random 4)
 (define grani-to-grain-allchans 5)
 
-(definstrument (grani start-time duration amplitude file :key
+(definstrument (grani start-time duration amplitude file
 		      (input-channel 0)
 		      (grains 0)
 		      (amp-envelope '(0 0 0.3 1 0.7 1 1 0))
@@ -449,193 +448,192 @@
 	 (where-bins-len (if (vct? where-bins) (length where-bins) 0)))
     (if reverse (set! (mus-increment in-file-reader) -1.0))
     (run
-     (lambda ()
-       (do () ((not happy))
-	 (if (< gr-offset gr-samples)
+     (do () ((not happy))
+       (if (< gr-offset gr-samples)
+	   ;;
+	   ;; send sample to output
+	   ;;
+	   (begin
+	     (if interp-gr-envs (set! gr-where (env gr-int-env)))
+	     (locsig loc (+ gr-start-sample gr-offset)
+		     (* (if interp-gr-envs
+			    (+ (* (- 1 gr-where) (table-lookup gr-env))
+			       (* gr-where (table-lookup gr-env-end)))
+			    (table-lookup gr-env))
+			(env amp-env)
+			(src in-file-reader)))
+	     ;; increment pointer in grain
+	     (set! gr-offset (+ 1 gr-offset)))
+	   (begin
 	     ;;
-	     ;; send sample to output
+	     ;; start of a new grain
 	     ;;
-	     (begin
-	       (if interp-gr-envs (set! gr-where (env gr-int-env)))
-	       (locsig loc (+ gr-start-sample gr-offset)
-		       (* (if interp-gr-envs
-			      (+ (* (- 1 gr-where) (table-lookup gr-env))
-				 (* gr-where (table-lookup gr-env-end)))
-			      (table-lookup gr-env))
-			  (env amp-env)
-			  (src in-file-reader)))
-	       ;; increment pointer in grain
-	       (set! gr-offset (+ 1 gr-offset)))
-	     (begin
-	       ;;
-	       ;; start of a new grain
-	       ;;
-	       (if first-grain
-		   ;; first grain always starts at 0
-		   (begin
-		     (set! first-grain #f)
-		     (set! gr-start-sample beg))
-		   (begin
-		     ;; start grain in output file using
-		     ;; increments from previous grain
-		     (set! gr-start-sample (+ gr-start-sample
-					      (floor 
-					       (* (/ (+ gr-dens gr-dens-spread)) (mus-srate)))))
-		     ;; finish if start of grain falls outside of note
-		     ;; bounds or number of grains exceeded
-		     (if (or (> gr-start-sample end)
-			     (if (not (zero? grains))
-				 (>= grain-counter grains)
-				 #f))
-			 (set! happy #f))))
-	       (if happy
-		   (begin
-	       ;; back to the beginning of the grain
-	       (set! gr-offset 0)
-	       ;; start of grain in samples from beginning of note
-	       (set! gr-from-beg (floor (- gr-start-sample beg)))
-	       ;; reset out-time dependent envelopes to current time
-	       (set! (mus-location amp-env) gr-from-beg)
-	       (set! (mus-location gr-dur) gr-from-beg)
-	       (set! (mus-location gr-dur-spread) gr-from-beg)
-	       (set! (mus-location sr-env) gr-from-beg)
-	       (set! (mus-location sr-spread-env) gr-from-beg)
-	       (set! (mus-location gr-start) gr-from-beg)
-	       (set! (mus-location gr-start-spread) gr-from-beg)
-	       (set! (mus-location gr-dens-env) gr-from-beg)
-	       (set! (mus-location gr-dens-spread-env) gr-from-beg)
-	       ;; start of grain in input file
-	       (set! in-start-value (+ (* (env gr-start) gr-start-scaler)
-				       (mus-random (* 0.5 (env gr-start-spread)
-						      gr-start-scaler))))
-	       (set! in-start (floor (* in-start-value in-file-sr)))
-	       ;; duration in seconds of the grain
-	       (set! gr-duration (max grain-duration-limit
-				      (+ (env gr-dur)
-					 (mus-random (* 0.5 (env gr-dur-spread))))))
-	       ;; number of samples in the grain
-	       (set! gr-samples (floor (* gr-duration (mus-srate))))
-	       ;; new sample rate for grain
-	       (set! gr-srate (if srate-linear
-				  (+ (env sr-env)
-				     (mus-random (* 0.5 (env sr-spread-env))))
-				  (* (env sr-env)
-				     (expt srate-base
-					   (mus-random (* 0.5 (env sr-spread-env)))))))
-	       ;; set new sampling rate conversion factor
-	       (set! (mus-increment in-file-reader) gr-srate)
-	       ;; number of samples in input
-	       (set! in-samples (floor (/ gr-samples (/ 1 srate-ratio))))
-	       ;; restart grain envelopes
-	       (set! (mus-phase gr-env) 0.0)
-	       (set! (mus-phase gr-env-end) 0.0)
-	       ;; reset grain envelope durations
-	       (set! (mus-frequency gr-env) (/ 1 gr-duration))
-	       (set! (mus-frequency gr-env-end) (/ 1 gr-duration))
-	       ;;
-	       ;; move position in output file for next grain
-	       ;;
-	       (set! gr-dens (env gr-dens-env))
-	       ;; increment spread in output file for next grain
-	       (set! gr-dens-spread (mus-random (* 0.5 (env gr-dens-spread-env))))
-	       ;; gather some statistics
-	       (set! samples (+ samples gr-samples))
-	       (set! grain-counter (+ grain-counter 1))
-	       (set! where (cond (;; use duration of grains as delimiter
-				  (= where-to grani-to-grain-duration)
-				  gr-duration)
-				 (;; use start in input file as delimiter
-				  (= where-to grani-to-grain-start)
-				  in-start-value)
-				 (;; use sampling rate as delimiter
-				  (= where-to grani-to-grain-sample-rate)
-				  gr-srate)
-				 (;; use a random number as delimiter
-				  (= where-to grani-to-grain-random)
-				  (random 1.0))
-				 (else grani-to-locsig)))
-	       (if (and (not (zero? where))
-			(vct? where-bins)
-			(> where-bins-len 1))
-		   ;; set output scalers according to criteria
-		   (do ((chn 0 (+ 1 chn)))
-		       ((or (= chn out-chans)
-			    (= chn where-bins-len)))
-		     (locsig-set! loc chn (if (< (vct-ref where-bins chn)
-						 where
-						 (vct-ref where-bins (+ 1 chn)))
-					      1.0
-					      0.0)))
-		   ;; if not "where" see if the user wants to send to all channels
-		   (if (= where-to grani-to-grain-allchans)
-		       ;; send the grain to all channels
+	     (if first-grain
+		 ;; first grain always starts at 0
+		 (begin
+		   (set! first-grain #f)
+		   (set! gr-start-sample beg))
+		 (begin
+		   ;; start grain in output file using
+		   ;; increments from previous grain
+		   (set! gr-start-sample (+ gr-start-sample
+					    (floor 
+					     (* (/ (+ gr-dens gr-dens-spread)) (mus-srate)))))
+		   ;; finish if start of grain falls outside of note
+		   ;; bounds or number of grains exceeded
+		   (if (or (> gr-start-sample end)
+			   (if (not (zero? grains))
+			       (>= grain-counter grains)
+			       #f))
+		       (set! happy #f))))
+	     (if happy
+		 (begin
+		   ;; back to the beginning of the grain
+		   (set! gr-offset 0)
+		   ;; start of grain in samples from beginning of note
+		   (set! gr-from-beg (floor (- gr-start-sample beg)))
+		   ;; reset out-time dependent envelopes to current time
+		   (set! (mus-location amp-env) gr-from-beg)
+		   (set! (mus-location gr-dur) gr-from-beg)
+		   (set! (mus-location gr-dur-spread) gr-from-beg)
+		   (set! (mus-location sr-env) gr-from-beg)
+		   (set! (mus-location sr-spread-env) gr-from-beg)
+		   (set! (mus-location gr-start) gr-from-beg)
+		   (set! (mus-location gr-start-spread) gr-from-beg)
+		   (set! (mus-location gr-dens-env) gr-from-beg)
+		   (set! (mus-location gr-dens-spread-env) gr-from-beg)
+		   ;; start of grain in input file
+		   (set! in-start-value (+ (* (env gr-start) gr-start-scaler)
+					   (mus-random (* 0.5 (env gr-start-spread)
+							  gr-start-scaler))))
+		   (set! in-start (floor (* in-start-value in-file-sr)))
+		   ;; duration in seconds of the grain
+		   (set! gr-duration (max grain-duration-limit
+					  (+ (env gr-dur)
+					     (mus-random (* 0.5 (env gr-dur-spread))))))
+		   ;; number of samples in the grain
+		   (set! gr-samples (floor (* gr-duration (mus-srate))))
+		   ;; new sample rate for grain
+		   (set! gr-srate (if srate-linear
+				      (+ (env sr-env)
+					 (mus-random (* 0.5 (env sr-spread-env))))
+				      (* (env sr-env)
+					 (expt srate-base
+					       (mus-random (* 0.5 (env sr-spread-env)))))))
+		   ;; set new sampling rate conversion factor
+		   (set! (mus-increment in-file-reader) gr-srate)
+		   ;; number of samples in input
+		   (set! in-samples (floor (/ gr-samples (/ 1 srate-ratio))))
+		   ;; restart grain envelopes
+		   (set! (mus-phase gr-env) 0.0)
+		   (set! (mus-phase gr-env-end) 0.0)
+		   ;; reset grain envelope durations
+		   (set! (mus-frequency gr-env) (/ 1 gr-duration))
+		   (set! (mus-frequency gr-env-end) (/ 1 gr-duration))
+		   ;;
+		   ;; move position in output file for next grain
+		   ;;
+		   (set! gr-dens (env gr-dens-env))
+		   ;; increment spread in output file for next grain
+		   (set! gr-dens-spread (mus-random (* 0.5 (env gr-dens-spread-env))))
+		   ;; gather some statistics
+		   (set! samples (+ samples gr-samples))
+		   (set! grain-counter (+ grain-counter 1))
+		   (set! where (cond (;; use duration of grains as delimiter
+				      (= where-to grani-to-grain-duration)
+				      gr-duration)
+				     (;; use start in input file as delimiter
+				      (= where-to grani-to-grain-start)
+				      in-start-value)
+				     (;; use sampling rate as delimiter
+				      (= where-to grani-to-grain-sample-rate)
+				      gr-srate)
+				     (;; use a random number as delimiter
+				      (= where-to grani-to-grain-random)
+				      (random 1.0))
+				     (else grani-to-locsig)))
+		   (if (and (not (zero? where))
+			    (vct? where-bins)
+			    (> where-bins-len 1))
+		       ;; set output scalers according to criteria
 		       (do ((chn 0 (+ 1 chn)))
-			   ((= chn out-chans))
-			 (locsig-set! loc chn 1.0))
-		       ;; "where" is zero or unknown: use normal n-channel locsig, 
-		       ;; only understands mono reverb and 1, 2 or 4 channel output
-		       (begin
-			 (set! (mus-location gr-dist) gr-from-beg)
-			 (set! (mus-location gr-dist-spread) gr-from-beg)
-			 (set! (mus-location gr-degree) gr-from-beg)
-			 (set! (mus-location gr-degree-spread) gr-from-beg)
-			 ;; set locsig parameters, for now only understands stereo
-			 (set! deg (+ (env gr-degree)
-				      (mus-random (* 0.5 (env gr-degree-spread)))))
-			 (set! dist (+ (env gr-dist)
-				       (mus-random (* 0.5 (env gr-dist-spread)))))
-			 (set! dist-scl (/ 1.0 (max dist 1.0)))
-			 (set! dist-rscl (/ 1.0 (sqrt (max dist 1.0))))
-			 (if *reverb*
-			     (locsig-reverb-set! loc 0 (* reverb-amount dist-rscl)))
-			 (if (= out-chans 1)
-			     (locsig-set! loc 0 dist-scl)
-			     (if (= out-chans 2)
-				 (let ((frac (/ (min 90.0 (max 0.0 deg)) 90.0))) 
-				   (locsig-set! loc 0 (* dist-scl (- 1.0 frac)))
-				   (locsig-set! loc 1 (* dist-scl frac)))
-				 (if (> out-chans 2)
-				     (begin
-				       (locsig-set! loc 0
-						    (if (<= 0 deg 90)
-							(* dist-scl
-							   (/ (- 90 deg) 90.0))
-							(if (<= 270 deg 360)
-							    (* dist-scl
-							       (/ (- deg 270) 90)) 
-							    0.0)))
-				       (locsig-set! loc 1
-						    (if (<= 90 deg 180)
-							(* dist-scl
-							   (/ (- 180 deg) 90.0))
+			   ((or (= chn out-chans)
+				(= chn where-bins-len)))
+			 (locsig-set! loc chn (if (< (vct-ref where-bins chn)
+						     where
+						     (vct-ref where-bins (+ 1 chn)))
+						  1.0
+						  0.0)))
+		       ;; if not "where" see if the user wants to send to all channels
+		       (if (= where-to grani-to-grain-allchans)
+			   ;; send the grain to all channels
+			   (do ((chn 0 (+ 1 chn)))
+			       ((= chn out-chans))
+			     (locsig-set! loc chn 1.0))
+			   ;; "where" is zero or unknown: use normal n-channel locsig, 
+			   ;; only understands mono reverb and 1, 2 or 4 channel output
+			   (begin
+			     (set! (mus-location gr-dist) gr-from-beg)
+			     (set! (mus-location gr-dist-spread) gr-from-beg)
+			     (set! (mus-location gr-degree) gr-from-beg)
+			     (set! (mus-location gr-degree-spread) gr-from-beg)
+			     ;; set locsig parameters, for now only understands stereo
+			     (set! deg (+ (env gr-degree)
+					  (mus-random (* 0.5 (env gr-degree-spread)))))
+			     (set! dist (+ (env gr-dist)
+					   (mus-random (* 0.5 (env gr-dist-spread)))))
+			     (set! dist-scl (/ 1.0 (max dist 1.0)))
+			     (set! dist-rscl (/ 1.0 (sqrt (max dist 1.0))))
+			     (if *reverb*
+				 (locsig-reverb-set! loc 0 (* reverb-amount dist-rscl)))
+			     (if (= out-chans 1)
+				 (locsig-set! loc 0 dist-scl)
+				 (if (= out-chans 2)
+				     (let ((frac (/ (min 90.0 (max 0.0 deg)) 90.0))) 
+				       (locsig-set! loc 0 (* dist-scl (- 1.0 frac)))
+				       (locsig-set! loc 1 (* dist-scl frac)))
+				     (if (> out-chans 2)
+					 (begin
+					   (locsig-set! loc 0
 							(if (<= 0 deg 90)
 							    (* dist-scl
-							       (/ deg 90)) 
-							    0.0)))
-				       (locsig-set! loc 2
-						    (if (<= 180 deg 270)
-							(* dist-scl
-							   (/ (- 270 deg) 90.0))
+							       (/ (- 90 deg) 90.0))
+							    (if (<= 270 deg 360)
+								(* dist-scl
+								   (/ (- deg 270) 90)) 
+								0.0)))
+					   (locsig-set! loc 1
 							(if (<= 90 deg 180)
 							    (* dist-scl
-							       (/ (- deg 90) 90)) 
-							    0.0)))
-				       (if (> out-chans 3)
-					   (locsig-set! loc 3
-							(if (<= 270 deg 360)
-							    (* dist-scl
-							       (/ (- 360 deg) 90.0))
-							    (if (<= 180 deg 270)
+							       (/ (- 180 deg) 90.0))
+							    (if (<= 0 deg 90)
 								(* dist-scl
-								   (/ (- deg 180) 90))
-								0.0)))))))))))))
-	       ;; check for out of bounds condition in in-file pointers
-	       (if (> (+ in-start in-samples) last-in-sample)
-		   (set! in-start (- last-in-sample in-samples))
-		   (if (< in-start 0)
-		       (set! in-start 0)))
-	       ;; reset position of input file reader
-	       (set! (mus-location rd) in-start))))))))
+								   (/ deg 90)) 
+								0.0)))
+					   (locsig-set! loc 2
+							(if (<= 180 deg 270)
+							    (* dist-scl
+							       (/ (- 270 deg) 90.0))
+							    (if (<= 90 deg 180)
+								(* dist-scl
+								   (/ (- deg 90) 90)) 
+								0.0)))
+					   (if (> out-chans 3)
+					       (locsig-set! loc 3
+							    (if (<= 270 deg 360)
+								(* dist-scl
+								   (/ (- 360 deg) 90.0))
+								(if (<= 180 deg 270)
+								    (* dist-scl
+								       (/ (- deg 180) 90))
+								    0.0)))))))))))))
+	     ;; check for out of bounds condition in in-file pointers
+	     (if (> (+ in-start in-samples) last-in-sample)
+		 (set! in-start (- last-in-sample in-samples))
+		 (if (< in-start 0)
+		     (set! in-start 0)))
+	     ;; reset position of input file reader
+	     (set! (mus-location rd) in-start)))))))
 
 ;; (with-sound (:channels 2 :reverb jc-reverb :reverb-channels 1) (let ((file "oboe.snd")) (grani 0 2 5 file :grain-envelope (raised-cosine))))
 ;; (with-sound (:channels 2) (let ((file "oboe.snd")) (grani 0 2 5 file :grain-envelope (raised-cosine))))
