@@ -1,8 +1,8 @@
 # hooks.rb -- hook-related functions
 
-# Author: Michael Scholz <scholz-micha@gmx.de>
+# Author: Michael Scholz <mi-scholz@users.sourceforge.net>
 # Created: Sun Dec 21 13:48:01 CET 2003
-# Last: Tue Mar 09 12:40:18 CET 2004
+# Changed: Wed Oct 14 23:11:31 CEST 2009
 
 # Commentary:
 #
@@ -34,10 +34,15 @@ end
 # $var_hook.member?("name of hook")
 # $var_hook.show or
 # describe_hook(hook)   prints code of hook procedures if file exists
+# $var.run_hook_by_name(name, *args)
+#
+# with_local_hook(hook, *procs, &thunk)
 # reset_all_hooks()     clears all hook procedures
 
 # Code:
 
+require "clm"
+
 unless defined?(Hook)
   class Hook
     include Enumerable
@@ -45,20 +50,12 @@ unless defined?(Hook)
     def initialize(name, arity = 0, help = "")
       @name = name
       @arity = arity
-      @help = help
       @procs = []
+      if string?(help) and (not help.empty?) then add_help(name, help) end
     end
-    attr_reader :name, :arity, :help
+    attr_reader :name, :arity
     
     def add_hook!(name, &body)
-      # We can't test any longer body.arity, because Proc#arity
-      # returns -1 in any case (as of CVS-Ruby 1.9.0, Mar 04, 2004).
-
-      # if body.arity == @arity
-      #   @procs.push([name, body])
-      # else
-      #   raise format("need a procedure of %d args, not %d", @arity, body.arity)
-      # end
       @procs.push([name, body])
     end
     
@@ -82,7 +79,7 @@ unless defined?(Hook)
     end
     
     def to_a
-      @procs.map do |x| x.last end
+      @procs.map do |ary| ary.last end
     end
     
     def length
@@ -95,18 +92,17 @@ unless defined?(Hook)
     end
 
     def describe
-      @help
+      get_help(@name)
     end
     alias documentation describe
     
     def names
-      @procs.map do |x| x.first end
+      @procs.map do |ary| ary.first end
     end
-    private :names
     
     def inspect
       format("#<%s name: %s, arity: %d, procs[%d]: %s>",
-             self.class, @name.inspect, @arity, self.length, names().inspect)
+             self.class, @name.inspect, @arity, self.length, self.names.inspect)
     end
   end
 
@@ -135,11 +131,13 @@ need a String or Symbol, not %s"
   end
   
   def hook?(obj)
-    defined?(Hook) ? obj.kind_of?(Hook) : false
+    obj.kind_of?(Hook)
   end
   
   $after_graph_hook             = Hook.new("$after_graph_hook", 2)
+  $after_lisp_graph_hook        = Hook.new("$after_lisp_graph_hook", 2)
   $lisp_graph_hook              = Hook.new("$lisp_graph_hook", 2)
+  $time_graph_hook              = Hook.new("$time_graph_hook", 2)
   $before_transform_hook        = Hook.new("$before_transform_hook", 2)
   $mix_release_hook             = Hook.new("$mix_release_hook", 2)
   $save_hook                    = Hook.new("$save_hook", 2)
@@ -152,7 +150,6 @@ need a String or Symbol, not %s"
   $close_hook                   = Hook.new("$close_hook", 1)
   $drop_hook                    = Hook.new("$drop_hook", 1)
   $update_hook                  = Hook.new("$update_hook", 1)
-  $just_sounds_hook             = Hook.new("$just_sounds_hook", 1)
   $mark_click_hook              = Hook.new("$mark_click_hook", 1)
   $mark_drag_hook               = Hook.new("$mark_drag_hook", 1)
   $name_click_hook              = Hook.new("$name_click_hook", 1)
@@ -171,9 +168,9 @@ need a String or Symbol, not %s"
   $select_sound_hook            = Hook.new("$select_sound_hook", 1)
   $print_hook                   = Hook.new("$print_hook", 1)
   $exit_hook                    = Hook.new("$exit_hook", 0)
-  $output_name_hook             = Hook.new("$output_name_hook", 0)
+  $output_name_hook             = Hook.new("$output_name_hook", 1)
   $during_open_hook             = Hook.new("$during_open_hook", 3)
-  $transform_hook               = Hook.new("$transform_hook", 3)
+  $after_transform_hook         = Hook.new("$after_transform_hook", 3)
   $mouse_enter_label_hook       = Hook.new("$mouse_enter_label_hook", 3)
   $mouse_leave_label_hook       = Hook.new("$mouse_leave_label_hook", 3)
   $initial_graph_hook           = Hook.new("$initial_graph_hook", 3)
@@ -186,39 +183,46 @@ need a String or Symbol, not %s"
   $mouse_click_hook             = Hook.new("$mouse_click_hook", 7)
   $new_widget_hook              = Hook.new("$new_widget_hook", 1)
   $mark_hook                    = Hook.new("$mark_hook", 4)
-  $previous_files_select_hook   = Hook.new("$previous_files_select_hook", 1)
+  $view_files_select_hook       = Hook.new("$view_files_select_hook", 2)
   $dac_hook                     = Hook.new("$dac_hook", 1)
   $stop_dac_hook                = Hook.new("$stop_dac_hook", 0)
   $stop_playing_selection_hook  = Hook.new("$stop_playing_selection_hook", 0)
-  $after_apply_hook             = Hook.new("$after_apply_hook", 1)
+  $after_apply_controls_hook    = Hook.new("$after_apply_controls_hook", 1)
   $draw_mark_hook               = Hook.new("$draw_mark_hook", 1)
+  $draw_mix_hook                = Hook.new("$draw_mix_hook", 5)
   $bad_header_hook              = Hook.new("$bad_header_hook", 1)
   $save_state_hook              = Hook.new("$save_state_hook", 1)
   $new_sound_hook               = Hook.new("$new_sound_hook", 1)
-  $color_hook                   = Hook.new("$color_hook", 0)
   $orientation_hook             = Hook.new("$orientation_hook", 0)
   $listener_click_hook          = Hook.new("$listener_click_hook", 1)
   $mix_click_hook               = Hook.new("$mix_click_hook", 1)
+  $before_save_state_hook       = Hook.new("$before_save_state_hook", 1)
   $after_save_state_hook        = Hook.new("$after_save_state_hook", 1)
   $mouse_enter_text_hook        = Hook.new("$mouse_enter_text_hook", 1)
   $mouse_leave_text_hook        = Hook.new("$mouse_leave_text_hook", 1)
   $optimization_hook            = Hook.new("$optimization_hook", 1)
-  $mix_drag_hook                = Hook.new("$mix_drag_hook", 1)
+  $mix_drag_hook                = Hook.new("$mix_drag_hook", 3)
   $mark_drag_triangle_hook      = Hook.new("$mark_drag_triangle_hook", 4)
   $start_playing_selection_hook = Hook.new("$start_playing_selection_hook", 0)
-  $selection_changed_hook       = Hook.new("$selection_changed_hook", 0)
+  $before_exit_hook             = Hook.new("$before_exit_hook", 0)
+  $before_close_hook            = Hook.new("$before_close_hook", 1)
+  $clip_hook                    = Hook.new("$clip_hook", 1)
   $after_save_as_hook           = Hook.new("$after_save_as_hook", 3)
+  $before_save_as_hook          = Hook.new("$before_save_as_hook", 7)
+  $peak_env_hook                = Hook.new("$peak_env_hook", 2)
   # unless --with-no-gui
-  $recorder_file_hook           = Hook.new("$recorder_file_hook", 1)
+  $color_hook                   = Hook.new("$color_hook", 0)
   # if --with-gtk
   $gtk_popup_hook               = Hook.new("$gtk_popup_hook", 5)
 end
 
-require "examp"
-
 class Hook
+  def to_names
+    @procs.map do |ary| ary.first end
+  end
+
   def member?(name)
-    @procs.map do |ary| ary.first end.member?(name)
+    to_names.member?(name)
   end
   alias included? member?
 
@@ -228,20 +232,42 @@ class Hook
   def to_str
     self.each do |prc|
       # cover printf's %x
-      rbm_message(prc.to_str.gsub(/%/, "%%"))
+      Snd.display(prc.to_str.gsub(/%/, "%%"))
     end
     nil
   end
   alias show to_str
+
+  def run_hook_by_name(name, *args)
+    if prc = @procs.assoc(name) then prc.last.call(*args) end
+  end
 end
 
 def describe_hook(hook)
   hook.show
 end
 
+add_help(:with_local_hook,
+         "with_local_hook(hook, *procs, &thunk)  \
+evaluates thunk with hook set to procs, then restores hook to its previous state")
+def with_local_hook(hook, *procs, &thunk)
+  old_procs = []
+  hook.to_names.each do |name| old_procs.push(hook.remove_hook!(name)) end
+  hook.reset_hook!
+  procs.each do |prc| hook.add_hook!(prc.object_id.to_s, &prc) end
+  thunk.call
+rescue Interrupt, ScriptError, StandardError
+  Snd.display(verbose_message_string(true, nil, get_func_name))
+ensure
+  hook.reset_hook!
+  old_procs.each do |name, prc| hook.add_hook!(name, &prc) end
+end
+
 if defined? $after_graph_hook
   Snd_hooks = [$after_graph_hook,
+               $after_lisp_graph_hook,
                $lisp_graph_hook,
+               $time_graph_hook,
                $before_transform_hook,
                $mix_release_hook,
                $save_hook,
@@ -254,7 +280,6 @@ if defined? $after_graph_hook
                $close_hook,
                $drop_hook,
                $update_hook,
-               $just_sounds_hook,
                $mark_click_hook,
                $mark_drag_hook,
                $name_click_hook,
@@ -275,7 +300,7 @@ if defined? $after_graph_hook
                $exit_hook,
                $output_name_hook,
                $during_open_hook,
-               $transform_hook,
+               $after_transform_hook,
                $mouse_enter_label_hook,
                $mouse_leave_label_hook,
                $initial_graph_hook,
@@ -288,19 +313,21 @@ if defined? $after_graph_hook
                $mouse_click_hook,
                $new_widget_hook,
                $mark_hook,
-               $previous_files_select_hook,
+               $view_files_select_hook,
                $dac_hook,
                $stop_dac_hook,
                $stop_playing_selection_hook,
-               $after_apply_hook,
+               $after_apply_controls_hook,
                $draw_mark_hook,
+               $draw_mix_hook,
                $bad_header_hook,
                $save_state_hook,
                $new_sound_hook,
-               $color_hook,
                $orientation_hook,
                $listener_click_hook,
                $mix_click_hook,
+               $peak_env_hook,
+               $before_save_state_hook,
                $after_save_state_hook,
                $mouse_enter_text_hook,
                $mouse_leave_text_hook,
@@ -308,22 +335,26 @@ if defined? $after_graph_hook
                $mix_drag_hook,
                $mark_drag_triangle_hook,
                $start_playing_selection_hook,
-               $selection_changed_hook,
                $after_save_as_hook,
-               unless $".member? "snd-nogui"
-                 $recorder_file_hook
-               end,
-               if $".member? "snd-gtk"
-                 $gtk_popup_hook
-               end]
+               $before_save_as_hook,
+               $before_exit_hook,
+               $clip_hook,
+               $before_close_hook]
 
+  unless provided? :snd_nogui
+    Snd_hooks.push($color_hook)
+  end
+  if provided? :snd_gtk
+    Snd_hooks.push($gtk_popup_hook)
+  end
+  
   def reset_all_hooks
-    Snd_hooks.each do |h| h.reset_hook! end
-    sounds.each do |snd|
+    Snd_hooks.each do |h| h.kind_of?(Hook) and h.reset_hook! end
+    Snd.sounds.each do |snd|
       channels(snd).times do |chn|
-        edit_hook(snd, chn).reset_hook! if hook?(edit_hook(snd, chn))
-        after_edit_hook(snd, chn).reset_hook! if hook?(after_edit_hook(snd, chn))
-        undo_hook(snd, chn).reset_hook! if hook?(undo_hook(snd, chn))
+        (h = edit_hook(snd, chn)).kind_of?(Hook)       and h.reset_hook!
+        (h = after_edit_hook(snd, chn)).kind_of?(Hook) and h.reset_hook!
+        (h = undo_hook(snd, chn)).kind_of?(Hook)       and h.reset_hook!
       end
     end
   end
