@@ -1,6 +1,5 @@
 ;;; hook-related functions
 
-(use-modules (ice-9 format))
 (provide 'snd-hooks.scm)
 
 ;;; -------- snd-hooks
@@ -36,34 +35,6 @@
    (sounds)))
 
 
-;;; -------- remove-local-hook!
-;;;
-;;; Guile's remove-hook! does not work with locally defined functions, and
-;;;   the functions themselves are not eq/eqv/equal to themselves!  So,
-;;;   we kludge around it using the procedure name as a string (but anonymous
-;;;   lambdas have #f for a name).
-
-(define (remove-local-hook! hook func)
-  "(remove-local-hook! hook func) removes func from hook even if func is defined locally"
-  (define (procedure-name-or-false f)
-    ;; anonymous lambda procedure name is #f
-    (let ((name (procedure-name f)))
-      (if name
-	  (symbol->string name)
-	  #f)))
-  (let ((name (procedure-name-or-false func)))
-    (if name
-	(let ((lst (hook->list hook)))
-	  (reset-hook! hook)
-	  (for-each (lambda (orig-func)
-		      (let ((orig-name (procedure-name-or-false orig-func)))
-			(if (not (and (string? orig-name)
-				      (string=? orig-name name)))
-			    (add-hook! hook orig-func))))
-		    lst))))
-  hook)
-
-
 ;;; -------- describe-hook
 
 (define (describe-hook hook)
