@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "1.39"
-#define S7_DATE "24-Nov-09"
+#define S7_VERSION "1.58"
+#define S7_DATE "2-June-10"
 
 
 typedef long long int s7_Int;
@@ -29,7 +29,7 @@ typedef double s7_Double;
    *
    * s7 (scheme) variables:
    *
-   *    *features*              a list of symbols describing what is current available (initially '(s7)).
+   *    *features*              a list of symbols describing what is currently available (initially '(s7)).
    *                               "provide" adds a symbol to the list, 
    *                               "provided?" returns #t if its symbol arg is in the list.
    *    *vector-print-length*   how many elements of a vector are printed (initially 8)
@@ -40,6 +40,8 @@ typedef double s7_Double;
    *                               the error type (a symbol), and the info about it (a list).
    *    *error-info*            data describing last error (see below).
    *    *trace-hook*            called upon trace (a function of two args)
+   *    *unbound-variable-hook* called when an unbound symbol is accessed.
+   *    *#readers*              #... readers
    *
    * s7 constants:
    *
@@ -65,31 +67,20 @@ typedef double s7_Double;
    *    trace and untrace       add or subtract functions from the trace list; (trace abs). 
    *    stacktrace              show a stack trace, the stack at the point of an error: (stacktrace *error-info*),
    *                               or the stack at a break point: (stacktrace break-continuation)
+   *    macro?                  returns #t is its argument is a macro or a symbol whose value is a macro
    *
    *    and various others mentioned at the start of s7.c -- nearly every Scheme implementation includes
    *    stuff like logior, sinh, read-line, format, define*, etc.  See also the start of s7.c for choices
    *    such as multiprecision arithmetic, multidimensional vectors, initial heap and stack size, etc.
    *
-   *    The functions length, copy, and fill! are generic.
-   *
-   * s7 non-standard object:
-   *  
-   *    encapsulator           a data "continuation" -- save the current environment for later restoration.
-   *       open-encapsulator        this returns an encapsulation that when called as a thunk restores the current environment
-   *       close-encapsulator       this closes (retires, puts an end to) an encapsulation
-   *       encapsulator-bindings    these are the currently saved bindings awaiting restoration
-   *       encapsulator?            #t if its argument is an encapsulator
-   * 
-   * --------------------------------------------------------------------------------
+   *    The functions map, for-each, length, copy, and fill! are generic.
    *
    * I think s7 has built-in support for srfi-6 (basic string ports), srfi-8 (receive), srfi-17 (generalized-set!), 
    *   srfi-18 (multithreading), srfi-28 (format, also nearly all of srfi-48), srfi-30 (block comments),
    *   srfi-88 (keywords(, and srfi-89 (define*).  It also supports the functionality of many others
    *   but under a slightly different syntax: srfi-69 (hash-tables), srfi-16 (define*), srfi-25 (multidimensional
    *   arrays).  srfi-98 would be trivial to add, and exists in snd as getenv.
-   * The srfi-1 (lists) and srfi-60 (bitwise ops) reference implementations can be loaded as is. If someone
-   *   is interested, I think syntax-rules et al are implemented in scheme somewhere, and these could be used
-   *   to load many other srfi's.
+   * The srfi-1 (lists) and srfi-60 (bitwise ops) reference implementations can be loaded as is.
    */
 
 
@@ -122,7 +113,7 @@ s7_scheme *s7_init(void);
    * s7_init creates the interpreter.
    */
 
-typedef s7_pointer (*s7_function)(s7_scheme *sc, s7_pointer args);   /* obj = func(s7, args) -- args is a list of arguments */
+typedef s7_pointer (*s7_function)(s7_scheme *sc, s7_pointer args);   /* that is, obj = func(s7, args) -- args is a list of arguments */
 
 
 s7_pointer s7_f(s7_scheme *sc);                                      /* #f */
@@ -235,7 +226,7 @@ void s7_remove_from_heap(s7_scheme *sc, s7_pointer x);
 
 bool s7_is_eq(s7_pointer a, s7_pointer b);                                   /* (eq? a b) */
 bool s7_is_eqv(s7_pointer a, s7_pointer b);                                  /* (eqv? a b) */
-bool s7_is_equal(s7_pointer a, s7_pointer b);                                /* (equal? a b) */
+bool s7_is_equal(s7_scheme *sc, s7_pointer a, s7_pointer b);                 /* (equal? a b) */
 
 
 bool s7_is_boolean(s7_pointer x);                                            /* (boolean? x) */
@@ -293,6 +284,7 @@ bool s7_is_real(s7_pointer p);                                               /*
 s7_Double s7_real(s7_pointer p);                                             /* scheme real -> C double */
 s7_pointer s7_make_real(s7_scheme *sc, s7_Double num);                       /* C double -> scheme real */
 s7_Double s7_number_to_real(s7_pointer x);                                   /* x can be any kind of number */
+s7_Int s7_number_to_integer(s7_pointer x);
 
 bool s7_is_ulong(s7_pointer arg);                                            /* returns true if arg is an unsigned long */
 unsigned long s7_ulong(s7_pointer p);                                        /* scheme unsigned long -> C */
@@ -330,8 +322,7 @@ int s7_vector_rank(s7_pointer vect);
 s7_Int *s7_vector_dimensions(s7_pointer vec);                                         /* dimensions */
 s7_Int *s7_vector_offsets(s7_pointer vec);                                            /* precalculated offsets to speed-up addressing */
 
-  /* if s7 is built with multidimensional and applicable vectors, 
-   *
+  /* 
    *  (vect i) is the same as (vector-ref vect i)
    *  (set! (vect i) x) is the same as (vector-set! vect i x)
    *  (vect i j k) accesses the 3-dimensional vect
@@ -340,52 +331,6 @@ s7_Int *s7_vector_offsets(s7_pointer vec);
    *  (make-vector '(2 3) 1.0) returns a 2-dim vector with all elements set to 1.0
    */
   
-  /* since vectors and lists are set-applicable, and length is generic, we can write a
-   *   generic FFT that accepts both types or any other object that follows this syntax.
-
-        (define* (cfft! data n (dir 1)) ; (complex data)
-          (if (not n) (set! n (length data)))
-          (do ((i 0 (+ i 1))
-               (j 0))
-              ((= i n))
-            (if (> j i)
-        	(let ((temp (data j)))
-        	  (set! (data j) (data i))
-        	  (set! (data i) temp)))
-            (let ((m (/ n 2)))
-              (do () 
-        	  ((or (< m 2) (< j m)))
-        	(set! j (- j m))
-        	(set! m (/ m 2)))
-              (set! j (+ j m))))
-          (let ((ipow (floor (log n 2)))
-        	(prev 1))
-            (do ((lg 0 (+ lg 1))
-        	 (mmax 2 (* mmax 2))
-        	 (pow (/ n 2) (/ pow 2))
-        	 (theta (make-rectangular 0.0 (* pi dir)) (* theta 0.5)))
-        	((= lg ipow))
-              (let ((wpc (exp theta))
-        	    (wc 1.0))
-        	(do ((ii 0 (+ ii 1)))
-        	    ((= ii prev))
-        	  (do ((jj 0 (+ jj 1))
-        	       (i ii (+ i mmax))
-        	       (j (+ ii prev) (+ j mmax)))
-        	      ((>= jj pow))
-        	    (let ((tc (* wc (data j))))
-        	      (set! (data j) (- (data i) tc))
-        	      (set! (data i) (+ (data i) tc))))
-        	  (set! wc (* wc wpc)))
-        	(set! prev mmax))))
-          data)
-        
-        > (cfft! (list 0.0 1+i 0.0 0.0))
-        (1+1i -1+1i -1-1i 1-1i)
-        > (cfft! (vector 0.0 1+i 0.0 0.0))
-        #(1+1i -1+1i -1-1i 1-1i)
-  */
-        
 
 bool s7_is_hash_table(s7_pointer p);                                        /* (hash-table? p) */
 s7_pointer s7_make_hash_table(s7_scheme *sc, s7_Int size);                  /* (make-hash-table size) */
@@ -394,7 +339,7 @@ s7_pointer s7_hash_table_ref(s7_scheme *sc, s7_pointer table, const char *name);
 s7_pointer s7_hash_table_set(s7_scheme *sc, s7_pointer table, const char *name, s7_pointer value);  
                                                                             /* (hash-table-set! table name value) */
   /* a hash-table is a vector of alists '((symbol value)), so to iterate over a hash-table
-   *   use vector-ref and cdr down the lists.  An entry defaults to '() -- see "apropos" below
+   *   use for-each which calls its function with each of these alists.  An entry defaults to nil.
    */
   /* hash-tables are applicable:
       (let ((hash (make-hash-table)))
@@ -427,16 +372,16 @@ const char *s7_get_output_string(s7_scheme *sc, s7_pointer out_port);       /* (
   /*    don't free the string */
 
 typedef enum {S7_READ, S7_READ_CHAR, S7_READ_LINE, S7_READ_BYTE, S7_PEEK_CHAR, S7_IS_CHAR_READY} s7_read_t;
-s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, char c, s7_pointer port));  
+s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, unsigned char c, s7_pointer port));  
 s7_pointer s7_open_input_function(s7_scheme *sc, s7_pointer (*function)(s7_scheme *sc, s7_read_t read_choice, s7_pointer port));
 void *s7_port_data(s7_pointer port);
 void *s7_port_set_data(s7_pointer port, void *stuff);
 
-char s7_read_char(s7_scheme *sc, s7_pointer port);                          /* (read-char port) */
-char s7_peek_char(s7_scheme *sc, s7_pointer port);                          /* (peek-char port) */
+int s7_read_char(s7_scheme *sc, s7_pointer port);                           /* (read-char port) */
+int s7_peek_char(s7_scheme *sc, s7_pointer port);                           /* (peek-char port) */
 s7_pointer s7_read(s7_scheme *sc, s7_pointer port);                         /* (read port) */
 void s7_newline(s7_scheme *sc, s7_pointer port);                            /* (newline port) */
-void s7_write_char(s7_scheme *sc, char c, s7_pointer port);                 /* (write-char c port) */
+void s7_write_char(s7_scheme *sc, int c, s7_pointer port);                  /* (write-char c port) */
 void s7_write(s7_scheme *sc, s7_pointer obj, s7_pointer port);              /* (write obj port) */
 void s7_display(s7_scheme *sc, s7_pointer obj, s7_pointer port);            /* (display obj port) */
 const char *s7_format(s7_scheme *sc, s7_pointer args);                      /* (format ... */
@@ -466,11 +411,14 @@ s7_pointer s7_gensym(s7_scheme *sc, const char *prefix);                    /* (
 
 bool s7_is_keyword(s7_pointer obj);                                         /* (keyword? obj) */
 s7_pointer s7_make_keyword(s7_scheme *sc, const char *key);                 /* (make-keyword key) */
-bool s7_keyword_eq_p(s7_pointer obj1, s7_pointer obj2);                     /* (eq? obj1 obj2) -- objs are keys */
+#define s7_keyword_eq_p(Obj1, Obj2) s7_is_eq(Obj1, Obj2)
 
+s7_pointer s7_symbol_access(s7_scheme *sc, s7_pointer sym);
+s7_pointer s7_symbol_set_access(s7_scheme *sc, s7_pointer symbol, s7_pointer funcs);
 
 s7_pointer s7_global_environment(s7_scheme *sc);                            /* (global-environment) */
 s7_pointer s7_current_environment(s7_scheme *sc);                           /* (current-environment) */
+s7_pointer s7_augment_environment(s7_scheme *sc, s7_pointer env, s7_pointer bindings);
 
   /* each environment is a list of the current frames (alists of symbols and values)
    *   and the global (top-level) definitions, a vector of alists (a hash-table).
@@ -513,36 +461,6 @@ s7_pointer s7_current_environment(s7_scheme *sc);                           /* (
 	             (apropos-1 (vector-ref frame i))))
 	         (apropos-1 frame)))
            (current-environment)))
-   *
-   * It's also possible to change the current environment:
-   *
-      (define (push-environment e binding)
-        (if (vector? (car e))
-            (begin
-              (set-cdr! e (list (car e)))
-              (set-car! e (list binding)))
-            (set-car! e (cons binding (car e)))))
-   
-      (define (pop-environment e)
-        (if (not (vector? (car e)))
-            (begin
-              (set-car! e (cadr e))
-              (set-cdr! e (cddr e)))))
-   
-      (define-macro (define! e var val) 
-        `(push-environment ,e (cons ',var ,val)))
-
-      (define (make-environment . initial-bindings)
-         (cons initial-bindings (global-environment)))
-
-   *   (let ((x 3)) 
-   *     (define! (current-environment) hi 21)
-   *     (+ x hi))
-   *   -> 24
-   *
-   *   (let ((x 32)) 
-   *     (eval `(+ x y) (make-environment '(x . 2) '(y . 4))))
-   *   -> 6
    */
 
 s7_pointer s7_name_to_value(s7_scheme *sc, const char *name);
@@ -584,6 +502,7 @@ void s7_for_each_symbol(s7_scheme *sc, bool (*symbol_func)(const char *symbol_na
 
 
 void s7_define(s7_scheme *sc, s7_pointer env, s7_pointer symbol, s7_pointer value);
+bool s7_is_defined(s7_scheme *sc, const char *name);
 void s7_define_variable(s7_scheme *sc, const char *name, s7_pointer value);
 void s7_define_constant(s7_scheme *sc, const char *name, s7_pointer value);
 bool s7_is_constant(s7_pointer p);
@@ -598,15 +517,14 @@ bool s7_is_constant(s7_pointer p);
    *    (define *features* '())
    *
    * s7_define_variable is simply s7_define with string->symbol and the global environment.
-   * s7_define_constant is s7_define_variable but makes its "definee" immutable.
-   * s7_define is equivalent to define! in scheme (see below).
+   * s7_define_constant is s7_define but makes its "definee" immutable.
+   * s7_define is equivalent to define in scheme, but takes place in the global environment.
    */
 
 bool s7_is_function(s7_pointer p); 
 s7_pointer s7_make_function(s7_scheme *sc, const char *name, s7_function fnc, int required_args, int optional_args, bool rest_arg, const char *doc);
 
 void s7_define_function(s7_scheme *sc, const char *name, s7_function fnc, int required_args, int optional_args, bool rest_arg, const char *doc);
-void s7_define_set_function(s7_scheme *sc, const char *name, s7_function fnc, int required_args, int optional_args, bool rest_arg, const char *doc);
 void s7_define_function_star(s7_scheme *sc, const char *name, s7_function fnc, const char *arglist, const char *doc);
 void s7_define_function_with_setter(s7_scheme *sc, const char *name, s7_function get_fnc, s7_function set_fnc, int req_args, int opt_args, const char *doc);
 
@@ -633,9 +551,6 @@ void s7_define_macro(s7_scheme *sc, const char *name, s7_function fnc, int requi
    *     s7_define_function(sc, "car", g_car, 1, 0, false, "(car obj)");
    *                                          one required arg, no optional arg, no "rest" arg
    *
-   * s7_define_set_function is the same as s7_define_function, but also informs the encapsulation
-   *   mechanism that the function sets something.
-   *
    * s7_define_function_with_setter defined a procedure-with-setter.
    *
    * s7_is_function returns true if its argument is a function defined in this manner.
@@ -643,7 +558,6 @@ void s7_define_macro(s7_scheme *sc, const char *name, s7_function fnc, int requi
    *
    * s7_define_macro defines a scheme macro; its arguments are not evaluated (unlike a function),
    *   but its returned value (assumed to be some sort of scheme expression) is evaluated.
-   *   See the example below.
    */
 
   /* In s7, (define* (name . args) body) or (define name (lambda* args body))
@@ -844,6 +758,30 @@ void s7_mark_object(s7_pointer p);
  * 
  *        s7 changes
  *
+ * 2-June:    removed procedure-with-setter-setter-arity and folded that info into procedure-arity (use cdddr).
+ * 22-May:    multidimensional vectors are no longer optional.
+ * 9-May:     s7_read_char and s7_peek_char have to return an int, not a char (<eof>=-1, but 255 is a legit char).
+ *            s7_write_char and s7_open_output_function have similar changes.
+ * 3-May:     *#readers* to customize #... reading.  Also nan? and infinite?.
+ *            multidimensional vector constants using #nD(...): (#2D((1 2 3) (4 5 6)) 0 0) -> 1.
+ * 15-Apr:    multiple-values support is now on the WITH_MULTIPLE_VALUES switch (default 1).
+ * 13-Apr:    removed hash-table|vector|string-for-each -- these are handled by for-each.
+ *            also removed vector-map -- map is generic, but always returns a list.
+ * 12-Apr:    removed immutable constant checks -- see s7.html.
+ * 7-Apr:     *unbound-variable-hook*.
+ *            augment-environment and s7_augment_environment.
+ * 29-Mar:    symbol-access, s7_symbol_access, s7_symbol_set_access.
+ *            C example of notification in s7.html.
+ * 25-Mar:    make-type.  s7_is_equal now includes an s7_scheme pointer as its first argument.
+ * 24-Mar:    s7_is_defined.
+ * 19-Mar:    removed encapsulation mechanism and s7_define_set_function.
+ * 18-Mar:    added macro?.
+ * 27-Feb:    removed r4rs-style macro syntax.
+ * 17-Feb:    s7_number_to_integer.
+ * 20-Jan-10: removed the stack function.
+ * --------
+ * 16-Dec:    hash-table-for-each.
+ * 1-Dec:     mpc versions before 0.8.0 are no longer supported.
  * 24-Nov:    define-macro* and defmacro*.
  *            force and delay included only if WITH_FORCE set, promise? removed.
  * 17-Nov:    s7_is_boolean no longer takes the s7_scheme argument.
