@@ -14,44 +14,7 @@
 
 /* these macros fix up argument order for setter procs in Scheme: (set! (proc a b) c) */
 /*    snd-edits has a 5 and a 10 case */
-#if HAVE_GUILE
-
-#define WITH_TWO_SETTER_ARGS(name_reversed, name) \
-static XEN name_reversed(XEN arg1, XEN arg2)		\
-{							\
-  if (XEN_NOT_BOUND_P(arg2))				\
-    return(name(arg1, XEN_UNDEFINED));			\
-  return(name(arg2, arg1));				\
-}
-
-#define WITH_THREE_SETTER_ARGS(name_reversed, name) \
-static XEN name_reversed(XEN arg1, XEN arg2, XEN arg3) \
-  {						       \
-    if (XEN_NOT_BOUND_P(arg2))			       \
-      return(name(arg1, XEN_UNDEFINED, XEN_UNDEFINED)); \
-    else {						\
-      if (XEN_NOT_BOUND_P(arg3))			\
-	return(name(arg2, arg1, XEN_UNDEFINED));	\
-      else return(name(arg3, arg1, arg2));		\
-}}
-
-#define WITH_FOUR_SETTER_ARGS(name_reversed, name) \
-static XEN name_reversed(XEN arg1, XEN arg2, XEN arg3, XEN arg4)	\
-{									\
-  if (XEN_NOT_BOUND_P(arg2))						\
-    return(name(arg1, XEN_UNDEFINED, XEN_UNDEFINED, XEN_UNDEFINED));	\
-  else {								\
-    if (XEN_NOT_BOUND_P(arg3))						\
-      return(name(arg2, arg1, XEN_UNDEFINED, XEN_UNDEFINED));		\
-    else {								\
-      if (XEN_NOT_BOUND_P(arg4))					\
-	return(name(arg3, arg1, arg2, XEN_UNDEFINED));			\
-      else return(name(arg4, arg1, arg2, arg3));			\
-}}}
-
-#else
-
-#if HAVE_S7
+#if HAVE_SCHEME
 
 #define WITH_TWO_SETTER_ARGS(name_reversed, name)	   \
   static s7_pointer name_reversed(s7_scheme *sc, s7_pointer args)   \
@@ -92,8 +55,6 @@ static XEN name_reversed(XEN arg1, XEN arg2, XEN arg3, XEN arg4)	\
 #define WITH_TWO_SETTER_ARGS(name_reversed, name)
 #define WITH_THREE_SETTER_ARGS(name_reversed, name)
 #define WITH_FOUR_SETTER_ARGS(name_reversed, name)
-
-#endif
 #endif
 
 #define ASSERT_SAMPLE_TYPE(Origin, Beg, Offset) \
@@ -349,6 +310,7 @@ typedef struct chan_info {
   mus_float_t *amp_control; /* local amp controls in snd-dac; should it be extended to other controls? */
   search_result_t last_search_result;
   bool just_zero, new_peaks, editable, tracking;
+  struct inset_graph_info_t *inset_graph; /* defined in snd-chn.c */
 #if HAVE_GL
   int gl_fft_list, gl_wavo_list;
 #endif
@@ -457,7 +419,7 @@ typedef struct snd_state {
   XEN search_proc;
   int file_sorters_size, file_filters_size;
   XEN file_sorters, file_filters;
-  int catch_exists, search_proc_loc, local_errno, local_open_errno;
+  int search_proc_loc, local_errno, local_open_errno;
   state_context *sgx;
   int position_slider_width, zoom_slider_width, toggle_size, channel_sash_indent, sash_size, channel_sash_size, sash_indent;
   int max_sounds, sound_sync_max;
@@ -476,10 +438,10 @@ typedef struct snd_state {
   channel_style_t Channel_Style;
   sound_style_t Sound_Style;
   show_axes_t Show_Axes;
-  char *Eps_File, *Temp_Dir, *Save_Dir, *Ladspa_Dir;
+  char *Eps_File, *Temp_Dir, *Save_Dir, *Ladspa_Dir, *Peak_Env_Dir;
   char *Listener_Font, *Axis_Label_Font, *Axis_Numbers_Font, *Tiny_Font, *Peaks_Font, *Bold_Peaks_Font;
   char *orig_listener_font, *orig_axis_label_font, *orig_axis_numbers_font, *orig_tiny_font, *orig_peaks_font, *orig_bold_peaks_font;
-  bool Verbose_Cursor, Trap_Segfault;
+  bool Verbose_Cursor, Trap_Segfault, With_Inset_Graph, With_Pointer_Focus;
   int Enved_Filter_Order;
   mus_float_t Eps_Left_Margin, Eps_Bottom_Margin, Eps_Size, Log_Freq_Start;
   mus_float_t Spectro_X_Scale, Spectro_Y_Scale, Spectro_Z_Scale, Spectro_Z_Angle, Spectro_X_Angle, Spectro_Y_Angle;
@@ -536,7 +498,6 @@ typedef struct snd_state {
   int zoom_focus_proc_loc;
   mus_float_t lin_dB;
   char *HTML_Dir, *HTML_Program, *Open_File_Dialog_Directory;
-  bool error_lock;
   char *io_error_info;
   int deferred_regions;
   open_requestor_t open_requestor;
@@ -561,7 +522,7 @@ typedef struct snd_state {
 #if HAVE_GL && MUS_WITH_GL2PS
   bool gl_printing;
 #endif
-#if HAVE_S7
+#if HAVE_SCHEME
   char listener_char;
 #endif
 } snd_state;
@@ -715,7 +676,6 @@ const char *io_error_name(io_error_t err);
   void snd_error(const char *format, ...);
   void snd_warning(const char *format, ...);
 #endif
-void snd_error_without_redirection_or_hook(const char *msg);
 void snd_error_without_format(const char *msg);
 void snd_warning_without_format(const char *msg);
 bool run_snd_error_hook(const char *msg);
@@ -1032,13 +992,6 @@ XEN eval_form_wrapper(void *data);
 XEN string_to_form(const char *data);
 char *g_print_1(XEN obj);
 XEN g_c_make_sampler(snd_fd *fd);
-#if HAVE_GUILE
-  XEN g_call0(XEN proc, const char *caller);
-  XEN g_call1(XEN proc, XEN arg, const char *caller);
-  XEN g_call2(XEN proc, XEN arg1, XEN arg2, const char *caller);
-  XEN g_call3(XEN proc, XEN arg1, XEN arg2, XEN arg3, const char *caller);
-  XEN g_call_any(XEN proc, XEN arglist, const char *caller);
-#endif
 char *procedure_ok(XEN proc, int args, const char *caller, const char *arg_name, int argn);
 bool procedure_arity_ok(XEN proc, int args);
 int snd_protect(XEN obj);
@@ -1329,6 +1282,10 @@ void reset_spectro(void);
 void cursor_moveto(chan_info *cp, mus_long_t samp);
 chan_info *which_channel(snd_info *sp, int y);
 
+void clear_inset_graph(chan_info *cp);
+void free_inset_graph(chan_info *cp);
+void draw_inset_line_cursor(chan_info *cp, axis_context *ax);
+
 void g_init_chn(void);
 XEN make_graph_data(chan_info *cp, int edit_pos, mus_long_t losamp, mus_long_t hisamp);
 void draw_graph_data(chan_info *cp, mus_long_t losamp, mus_long_t hisamp, int data_size, mus_float_t *data, mus_float_t *data1, axis_context *ax, graph_style_t style);
@@ -1451,6 +1408,10 @@ int xen_sound_to_int(XEN n);
 #define C_INT_TO_XEN_SOUND(Val) new_xen_sound(Val)
 #define XEN_SOUND_TO_C_INT(n) xen_sound_to_int(n)
 
+const char *read_peak_env_info_file(chan_info *cp);
+bool write_peak_env_info_file(chan_info *cp);
+void delete_peak_env_info_file(chan_info *cp);
+
 
 
 /* -------- snd-file -------- */
@@ -1636,9 +1597,9 @@ void syncd_mix_unset_color(int id);
 void syncd_mix_set_amp(int id, mus_float_t amp);
 void syncd_mix_set_speed(int id, mus_float_t amp);
 void syncd_mix_set_amp_env(int id, env *e);
-void syncd_mix_set_position(int mix_id, mus_long_t pos);
 void syncd_mix_play(int id);
 void mix_unset_color_from_id(int id);
+color_t mix_color_from_id(int mix_id);
 color_t mix_set_color_from_id(int id, color_t new_color);
 void start_dragging_syncd_mixes(int mix_id);
 void keep_dragging_syncd_mixes(int mix_id);
@@ -1694,9 +1655,6 @@ void snd_set_global_defaults(bool need_cleanup);
 #if SND_AS_WIDGET
   snd_state *snd_main(int argc, char **argv);
 #endif
-#ifdef SND_AS_PD_EXTERNAL
-  int snd_pd_main(void);
-#endif
 void g_init_base(void);
 
 
@@ -1767,6 +1725,7 @@ axis_info *get_ap(chan_info *cp, axis_info_t ap_id, const char *caller);
 void g_init_draw(void);
 void set_dialog_widget(snd_dialog_t which, widget_t wid);
 void run_new_widget_hook(widget_t w);
+bool foreground_color_ok(XEN color, axis_context *ax);
 
 #if HAVE_GL
   void sgl_save_currents(void);
