@@ -1,11 +1,5 @@
 #include "snd.h"
 
-/* PERHAPS: in s7, it is possible to call s7_make_continuation in the error handler,
- *            passing that back to the caller in some way (a variable?), so that
- *            it is possible to go on from the error -- perhaps continuable errors
- *            could use XEN_CERROR?
- */
-
 static const char *io_error_names[IO_ERROR_NUM] = {"no error", "save-hook cancellation", "bad channel",
 						   "can't reopen file", "too many open files", "unknown sndlib error", 
 						   "no memory", "can't open", "no filename", "bad data format", "bad header type", "sndlib uninitialized", 
@@ -89,32 +83,28 @@ static void snd_error_1(const char *msg, bool with_redirection_and_hook)
       if (run_snd_error_hook(msg))
 	return;
     }
-#if USE_NO_GUI
+#if (USE_NO_GUI) || (MUS_DEBUGGING)
   fprintf(stderr, "%s", msg);
 #else
   if ((ss) && (ss->sgx))
     {
-      if ((MUS_DEBUGGING) || (ss->batch_mode))
+      if (ss->batch_mode)
 	fprintf(stderr, "%s", msg);
 #ifdef SND_AS_WIDGET
       if (snd_error_display) 
-	snd_error_display(msg);
-      else
 	{
-	  /* don't break (unlikely) existing code? */
-#endif
-	  {
-	    snd_info *sp;
-	    sp = any_selected_sound();
-	    if (ss->catch_exists == 0) /* not from xen(?) */
-	      {
-		if ((sp) && (sp->active))
-		  display_minibuffer_error(sp, msg);
-		else post_it("Error", msg);
-	      }
-	  }
-#ifdef SND_AS_WIDGET
+	  snd_error_display(msg);
+	  return;
 	}
+#endif
+#if ((!HAVE_EXTENSION_LANGUAGE) && (!USE_NO_GUI))
+      {
+	snd_info *sp;
+	sp = any_selected_sound();
+	if ((sp) && (sp->active))
+	  display_minibuffer_error(sp, msg);
+	else post_it("Error", msg);
+      }
 #endif
     }
   else 
@@ -238,12 +228,6 @@ void snd_error(const char *format, ...)
 }
 
 
-void snd_error_without_redirection_or_hook(const char *msg)
-{
-  snd_error_1(msg, false);
-}
-
-
 void snd_error_without_format(const char *msg)
 {
   snd_error_1(msg, true);
@@ -260,7 +244,7 @@ static XEN g_snd_error(XEN msg)
 
   if (!(run_snd_error_hook(XEN_TO_C_STRING(msg)))) /* have to call this before the throw, else we end up at top level */
     XEN_ERROR(XEN_ERROR_TYPE("snd-error"),
-	      XEN_LIST_2(C_TO_XEN_STRING(S_snd_error),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_snd_error ": ~A"),
 			 msg));
   return(msg);
 }
