@@ -25,7 +25,11 @@
 typedef enum {WITH_DEFAULT_BACKGROUND, WITH_WHITE_BACKGROUND} snd_entry_bg_t;
 
 #define widget_t GtkWidget*
-#define widget_is_active(Wid) GTK_WIDGET_VISIBLE(Wid)
+#if defined(GTK_WIDGET_VISIBLE)
+  #define widget_is_active(Wid) GTK_WIDGET_VISIBLE(Wid)
+#else
+  #define widget_is_active(Wid) gtk_widget_get_visible(Wid)
+#endif
 #define activate_widget(Wid) gtk_widget_show(Wid)
 #define deactivate_widget(Wid) gtk_widget_hide(Wid)
 
@@ -78,22 +82,18 @@ typedef enum {WITH_DEFAULT_BACKGROUND, WITH_WHITE_BACKGROUND} snd_entry_bg_t;
 #define TOGGLE_BUTTON_ACTIVE(Button) gtk_toggle_button_get_active((GTK_TOGGLE_BUTTON(Button)))
 #define BIN_CHILD(Bin) gtk_bin_get_child(GTK_BIN(Bin))
 
-#define EVENT_STATE(Ev) (Ev)->state
-/* perhaps #define EVENT_STATE(Ev) ({ GdkModifierType type;  gdk_event_get_state(Ev, &Type); Type; })
-   do we need GDK_EVENT_ANY(Ev)?
-*/
-
-#define EVENT_TIME(Ev) (Ev)->time
-/* perhaps #define EVENT_TIME(Ev) gdk_event_get_time(Ev)
- */
-
-#define EVENT_X(Ev) (Ev)->x
-/* perhaps #define EVENT_X(Ev) ({ gdouble x, y; gdk_event_get_coords(Ev, &x, &y); x; })
- */
-
-#define EVENT_Y(Ev) (Ev)->y
-/* perhaps #define EVENT_Y(Ev) ({ gdouble x, y; gdk_event_get_coords(Ev, &x, &y); y; })
- */
+#if (HAVE_GTK_SCALE_NEW) && defined(__GNUC__) && (!(defined(__cplusplus)))
+  #define EVENT_STATE(Ev) ({ GdkModifierType Type;  gdk_event_get_state((GdkEvent *)Ev, &Type); Type; })
+  #define EVENT_TIME(Ev) gdk_event_get_time((GdkEvent *)Ev)
+  #define EVENT_X(Ev) ({ gdouble x, y; gdk_event_get_coords((GdkEvent *)Ev, &x, &y); x; })
+  #define EVENT_Y(Ev) ({ gdouble x, y; gdk_event_get_coords((GdkEvent *)Ev, &x, &y); y; })
+  /* there's also gtk_get_event_widget */
+#else
+  #define EVENT_STATE(Ev) (Ev)->state
+  #define EVENT_TIME(Ev) (Ev)->time
+  #define EVENT_X(Ev) (Ev)->x
+  #define EVENT_Y(Ev) (Ev)->y
+#endif
 
 /* no accessors: */
 #define EVENT_WINDOW(Ev)      (Ev)->window
@@ -135,11 +135,6 @@ typedef enum {WITH_DEFAULT_BACKGROUND, WITH_WHITE_BACKGROUND} snd_entry_bg_t;
 
   #define picture_t GdkPixmap
 
-  #define XEN_WRAP_PIXEL(Value)    XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("color_t"), XEN_WRAP_C_POINTER((unsigned long)Value))
-  #define XEN_UNWRAP_PIXEL(Value)  (color_t)(XEN_UNWRAP_C_POINTER(XEN_CADR(Value)))
-  #define XEN_PIXEL_P(Value)       (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
-                                    (strcmp("color_t", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
-
 #else
 
   #define rgb_t unsigned short
@@ -151,11 +146,6 @@ typedef enum {WITH_DEFAULT_BACKGROUND, WITH_WHITE_BACKGROUND} snd_entry_bg_t;
   #define picture_t GdkPixmap
   typedef GdkColor* color_t;
   #define color_info GdkColor
-
-  #define XEN_WRAP_PIXEL(Value)    XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("GdkColor_"), XEN_WRAP_C_POINTER((unsigned long)Value))
-  #define XEN_UNWRAP_PIXEL(Value)  (GdkColor*)(XEN_UNWRAP_C_POINTER(XEN_CADR(Value)))
-  #define XEN_PIXEL_P(Value)       (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
-                                    (strcmp("GdkColor_", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
 #endif
 
 typedef struct {
@@ -298,7 +288,7 @@ typedef enum {WITHOUT_COMMENT_FIELD, WITH_COMMENT_FIELD} dialog_comment_t;
 
 #define snd_ShiftMask GDK_SHIFT_MASK
 #define snd_ControlMask GDK_CONTROL_MASK
-#ifndef MUS_SUN
+#if (!HAVE_SUN)
   #define snd_MetaMask GDK_MOD1_MASK
 #else
   #define snd_MetaMask (GDK_MOD1_MASK | GDK_MOD4_MASK)
