@@ -53,7 +53,7 @@ bool channel_graph_is_visible(chan_info *cp)
   return((cp) &&
 	 (cp->cgx) &&
 	 (channel_graph(cp)) &&
-	 (GTK_WIDGET_VISIBLE(channel_graph(cp))) &&
+	 (widget_is_active(channel_graph(cp))) &&
 	 (cp->sound) &&
 	 /* here we may have a sound wrapper for variable display in which case the sound widgets are not implemented */
 	 (((cp->sound->inuse == SOUND_WRAPPER) || (cp->sound->inuse == SOUND_REGION)) ||
@@ -61,7 +61,7 @@ bool channel_graph_is_visible(chan_info *cp)
 	   /* other choice: SOUND_IDLE -> no display */
 	   (cp->sound->sgx) &&
 	   (w_snd_pane(cp->sound)) &&
-	   (GTK_WIDGET_VISIBLE(w_snd_pane(cp->sound))))));
+	   (widget_is_active(w_snd_pane(cp->sound))))));
 }
 
 
@@ -412,6 +412,10 @@ static gboolean graph_mouse_enter(GtkWidget *w, GdkEventCrossing *ev, gpointer d
 {
   /* how many args does this thing take?  does it return an int?  what does the return value mean? */
   int pdata;
+
+  if (with_pointer_focus(ss))
+    goto_window(w);
+
   pdata = get_user_int_data(G_OBJECT(w));
   if (XEN_HOOKED(mouse_enter_graph_hook))
     run_hook(mouse_enter_graph_hook,
@@ -1357,50 +1361,6 @@ static XEN g_in(XEN ms, XEN code)
 }
 
 
-static XEN g_color_to_list(XEN obj)
-{
-  #define H_color_to_list "(" S_color_to_list " obj): 'obj' rgb values as a list of floats"
-  color_info *v;
-  XEN_ASSERT_TYPE(XEN_PIXEL_P(obj), obj, XEN_ONLY_ARG, S_color_to_list, "a color"); 
-  v = XEN_UNWRAP_PIXEL(obj);
-  return(xen_return_first(XEN_LIST_3(C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->red)),
-				     C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->green)),
-				     C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->blue))),
-			  obj));
-}
-
-
-static XEN g_make_color(XEN r, XEN g, XEN b)
-{
-  #define H_make_color "(" S_make_color " r g b): return a color object with the indicated rgb values"
-  color_info *ccolor;
-  mus_float_t rf, gf, bf;
-
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(r), r, XEN_ARG_1, S_make_color, "a number");
-  /* someday accept a list as r */
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(g), g, XEN_ARG_2, S_make_color, "a number");
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(b), b, XEN_ARG_3, S_make_color, "a number");
-
-  rf = check_color_range(S_make_color, r);
-  gf = check_color_range(S_make_color, g);
-  bf = check_color_range(S_make_color, b);
-#if USE_CAIRO
-  ccolor = (color_info *)calloc(1, sizeof(color_info)); /* memleak here -- need color smob + free to deal with this */
-  ccolor->red = rf;
-  ccolor->green = gf;
-  ccolor->blue = bf;
-#else
-  color_info gcolor;
-  gcolor.red = FLOAT_TO_RGB(rf);
-  gcolor.green = FLOAT_TO_RGB(gf);
-  gcolor.blue = FLOAT_TO_RGB(bf);
-  ccolor = gdk_color_copy(&gcolor);
-  gdk_rgb_find_color(gdk_colormap_get_system(), ccolor);
-#endif
-  return(XEN_WRAP_PIXEL(ccolor));
-}
-
-
 void color_unselected_graphs(color_t color)
 {
   int i;
@@ -1476,15 +1436,11 @@ static XEN g_set_graph_cursor(XEN curs)
 
 #ifdef XEN_ARGIFY_1
 XEN_NARGIFY_2(g_in_w, g_in)
-XEN_NARGIFY_3(g_make_color_w, g_make_color)
-XEN_NARGIFY_1(g_color_to_list_w, g_color_to_list)
 XEN_NARGIFY_0(g_graph_cursor_w, g_graph_cursor)
 XEN_NARGIFY_1(g_set_graph_cursor_w, g_set_graph_cursor)
 XEN_ARGIFY_2(g_channel_widgets_w, g_channel_widgets)
 #else
 #define g_in_w g_in
-#define g_make_color_w g_make_color
-#define g_color_to_list_w g_color_to_list
 #define g_graph_cursor_w g_graph_cursor
 #define g_set_graph_cursor_w g_set_graph_cursor
 #define g_channel_widgets_w g_channel_widgets
@@ -1494,8 +1450,6 @@ XEN_ARGIFY_2(g_channel_widgets_w, g_channel_widgets)
 void g_init_gxchn(void)
 {
   XEN_DEFINE_PROCEDURE(S_in,            g_in_w,             2, 0, 0, H_in);
-  XEN_DEFINE_PROCEDURE(S_make_color,    g_make_color_w,     3, 0, 0, H_make_color);
-  XEN_DEFINE_PROCEDURE(S_color_to_list, g_color_to_list_w,  1, 0, 0, H_color_to_list);
 
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_graph_cursor, g_graph_cursor_w, H_graph_cursor,
 				   S_setB S_graph_cursor, g_set_graph_cursor_w,  0, 0, 1, 0);
