@@ -233,8 +233,7 @@ void listener_append_and_prompt(const char *msg)
 
 static void listener_return_callback(void)
 {
-  if (!(ss->error_lock))
-    listener_return(listener_text, printout_end);
+  listener_return(listener_text, printout_end);
 }
 
 
@@ -539,7 +538,7 @@ static gboolean listener_key_press(GtkWidget *w, GdkEventKey *event, gpointer da
       return(true); /* don't repeat the keystroke */
     }
 
-#if HAVE_S7
+#if HAVE_SCHEME
   /* TODO: set ss->listener_char = char */
 #endif
 
@@ -713,6 +712,9 @@ static bool cursor_set_blinks(GtkWidget *w, bool blinks)
 
 static gboolean listener_focus_callback(GtkWidget *w, GdkEventCrossing *ev, gpointer unknown)
 {
+  if (with_pointer_focus(ss))
+    goto_window(listener_text);
+
   if (XEN_HOOKED(mouse_enter_listener_hook))
     run_hook(mouse_enter_listener_hook,
 	     XEN_LIST_1(XEN_WRAP_WIDGET(listener_text)),
@@ -735,7 +737,11 @@ static gboolean listener_unfocus_callback(GtkWidget *w, GdkEventCrossing *ev, gp
 
 static gboolean mouse_enter_text_callback(GtkWidget *w, GdkEventCrossing *ev, gpointer unknown)
 {
+  if (with_pointer_focus(ss))
+    goto_window(w);
+
   widget_modify_base(w, GTK_STATE_NORMAL, ss->sgx->white);
+
   if (XEN_HOOKED(mouse_enter_text_hook))
     run_hook(mouse_enter_text_hook,
 	     XEN_LIST_1(XEN_WRAP_WIDGET(w)),
@@ -1002,7 +1008,7 @@ bool listener_exists(void)
 
 int listener_height(void) 
 {
-  if ((listener_text) && (GTK_WIDGET_VISIBLE(listener_text)))
+  if ((listener_text) && (widget_is_active(listener_text)))
     return(widget_height(listener_text));
   else return(0);
 }
@@ -1010,7 +1016,7 @@ int listener_height(void)
 
 int listener_width(void) 
 {
-  if ((listener_text) && (GTK_WIDGET_VISIBLE(listener_text)))
+  if ((listener_text) && (widget_is_active(listener_text)))
     return(widget_width(listener_text)); 
   else return(0);
 }
