@@ -102,6 +102,7 @@ int find_matching_paren(const char *str, int parens, int pos, int *highlight_pos
   return(parens);
 }
 
+/* this doesn't know about block comments */
 
 int check_balance(const char *expr, int start, int end, bool in_listener) 
 {
@@ -174,9 +175,34 @@ int check_balance(const char *expr, int start, int end, bool in_listener)
 	    return(i);
 	  else 
 	    {
-	      if ((prev_separator) && (i + 1 < end) && (expr[i + 1] =='('))
-		i++;
-	      else
+	      bool found_it = false;
+	      if (prev_separator)
+		{
+		  int k, incr = 0;
+		  for (k = i + 1; k < end; k++)
+		    {
+		      if (expr[k] == '(')
+			{
+			  incr = k - i;
+			  break;
+			}
+		      else
+			{
+			  if ((!isdigit(expr[k])) &&
+			      (expr[k] != 'D') && 
+			      (expr[k] != 'd') &&
+			      (expr[k] != '=') &&
+			      (expr[k] != '#'))
+			    break;
+			}
+		    }
+		  if (incr > 0)
+		    {
+		      i += incr;
+		      found_it = true;
+		    }
+		}
+	      if (!found_it)
 		{
 		  if ((i + 2 < end) && (expr[i + 1] == '\\') && 
 		      ((expr[i + 2] == ')') || (expr[i + 2] == ';') || (expr[i + 2] == '\"') || (expr[i + 2] == '(')))
@@ -219,6 +245,7 @@ int check_balance(const char *expr, int start, int end, bool in_listener)
 	  break;
 
 	case '\'' :
+	case '`' :                  /* `(1 2) */
 	  if (prev_separator) 
 	    quote_wait = true;
 	  non_whitespace_p = true;
@@ -404,16 +431,16 @@ void listener_return(widget_t w, int last_prompt)
   last_position = GUI_TEXT_END(w);
   add_listener_position(last_position);
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
   if (XEN_HOOKED(read_hook))
     {
       XEN result;
       int len;
-      len = last_position - last_prompt + 1;
+      len = last_position - last_prompt;
       if (len > 0)
 	{
-	  str = (char *)calloc(len, sizeof(char));
-	  for (i = last_prompt + 1, j = 0; i < last_position; i++, j++) str[j] = full_str[i];
+	  str = (char *)calloc(len + 1, sizeof(char)); 
+	  for (i = last_prompt, j = 0; i < last_position; i++, j++) str[j] = full_str[i]; 
 	  result = run_or_hook(read_hook, 
 			       XEN_LIST_1(C_TO_XEN_STRING(str)),
 			       S_read_hook);
@@ -612,16 +639,11 @@ void listener_return(widget_t w, int last_prompt)
        *   I assume the form is ok because the continuation will preserve it somehow.
        */
 
-#if HAVE_GUILE
-      if ((mus_strlen(str) > 1) || (str[0] != '\n'))
-	form = string_to_form(str);
-#endif
-
 #if HAVE_RUBY || HAVE_FORTH
       form = XEN_EVAL_C_STRING(str);
 #endif
 
-#if HAVE_S7
+#if HAVE_SCHEME
       /* TODO: need a catch here if user has called read-line of listener-input-port, or perhaps earlier in listener_return_callback (snd-g|xlistener) */
 
       if ((mus_strlen(str) > 1) || (str[0] != '\n'))
@@ -660,11 +682,8 @@ void listener_return(widget_t w, int last_prompt)
       free(str);
       str = NULL;
 
-      /* in the Guile case, an error goes to snd_catch_scm_error -> listener_append_and_prompt ultimately */
       if (!got_error)
-	snd_report_listener_result(form); /* used to check for unbound form here, but that's no good in Ruby,
-					   *   and doesn't seem sensible in Guile
-					   */
+	snd_report_listener_result(form); /* used to check for unbound form here, but that's no good in Ruby */
       GUI_UNSET_CURSOR(w, ss->sgx->arrow_cursor);
     }
   else
@@ -697,7 +716,7 @@ static XEN g_save_listener(XEN filename)
     }
   if ((!fp) || (err == -1))
     XEN_ERROR(CANNOT_SAVE,
-	      XEN_LIST_3(C_TO_XEN_STRING(S_save_listener),
+	      XEN_LIST_3(C_TO_XEN_STRING(S_save_listener ": can't save ~S, ~A"),
 			 filename,
 			 C_TO_XEN_STRING(snd_io_strerror())));
   return(filename);
@@ -712,12 +731,9 @@ static XEN g_clear_listener(void)
 }
 
 
-static XEN g_show_listener(XEN val) 
+static XEN g_show_listener(void) 
 {
-  #define H_show_listener "(" S_show_listener " :optional (open " PROC_TRUE ")): if 'open' opens the lisp listener; returns whether the listener is visible."
-  XEN_ASSERT_TYPE(XEN_BOOLEAN_IF_BOUND_P(val), val, XEN_ONLY_ARG, S_show_listener, "a boolean");
-  if ((XEN_NOT_BOUND_P(val)) || (!(XEN_FALSE_P(val)))) /* explicit #f arg turns off listener creation/display */
-    handle_listener(true); 
+  #define H_show_listener "(" S_show_listener ") returns " PROC_TRUE " if the listener is open, otherwise " PROC_FALSE "."
   return(C_TO_XEN_BOOLEAN(listener_is_visible()));
 }
 
@@ -745,18 +761,11 @@ void set_listener_prompt(const char *new_prompt)
     free(str);
 #endif
 
-#if HAVE_GUILE
-    char *str;
-    str = mus_format("(set! scm-repl-prompt \"%s\")", listener_prompt(ss)); /* defined in ice-9/boot9.scm */
-    XEN_EVAL_C_STRING(str);
-    free(str);
-#endif
-
 #if HAVE_RUBY
     xen_rb_repl_set_prompt(listener_prompt(ss));
 #endif
 
-#if HAVE_S7
+#if HAVE_SCHEME
     xen_s7_set_repl_prompt(listener_prompt(ss));
 #endif
   }
@@ -804,7 +813,7 @@ static XEN g_snd_completion(XEN text)
 #ifdef XEN_ARGIFY_1
 XEN_NARGIFY_1(g_save_listener_w, g_save_listener)
 XEN_NARGIFY_0(g_clear_listener_w, g_clear_listener);
-XEN_ARGIFY_1(g_show_listener_w, g_show_listener)
+XEN_NARGIFY_0(g_show_listener_w, g_show_listener)
 XEN_NARGIFY_1(g_set_show_listener_w, g_set_show_listener)
 XEN_NARGIFY_0(g_listener_prompt_w, g_listener_prompt)
 XEN_NARGIFY_1(g_set_listener_prompt_w, g_set_listener_prompt)
@@ -825,7 +834,7 @@ void g_init_listener(void)
   XEN_DEFINE_PROCEDURE(S_clear_listener, g_clear_listener_w, 0, 0, 0, H_clear_listener);
 
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_show_listener, g_show_listener_w, H_show_listener,
-				   S_setB S_show_listener, g_set_show_listener_w,  0, 1, 1, 0);
+				   S_setB S_show_listener, g_set_show_listener_w,  0, 0, 1, 0);
 
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_listener_prompt, g_listener_prompt_w, H_listener_prompt,
 				   S_setB S_listener_prompt, g_set_listener_prompt_w,  0, 0, 1, 0);
