@@ -272,14 +272,17 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   snd_info *sp;
   int snd_slot, nchans, i;
   bool free_filename = false;
+
   if (ss->translated_filename) 
     {
       filename = ss->translated_filename;
       free_filename = true;
       ss->translated_filename = NULL;
     }
+
   nchans = hdr->chans;
   if (nchans <= 0) nchans = 1;
+
   if (nchans > 256)
     {
       /* either a screwed up header, or Snd was built with wrong endianess */
@@ -291,16 +294,21 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
 	fprintf(stderr, _("byte swap problem: chans should be %d"), mus_char_to_lint((unsigned char *)&nchans));
       nchans = 1; /* ?? */
     }
+
   snd_slot = find_free_sound_slot(nchans); /* expands sound list if needed */
   ss->sounds[snd_slot] = make_snd_info(ss->sounds[snd_slot], filename, hdr, snd_slot, read_only);
   sp = ss->sounds[snd_slot];
+
+  sp->write_date = file_write_date(filename); /* needed early in this process by the peak-env handlers */
   for (i = 0; i < nchans; i++) sp->chans[i] = make_chan_info(sp->chans[i], i, sp);
   add_sound_data(filename, sp, WITHOUT_GRAPH);
   after_open(sp->index);
+
   if (free_filename) free(filename);
   return(sp);
 }
 
+
 static char **auto_open_file_names = NULL;
 static int auto_open_files = 0;
 static bool noglob = false, noinit = false, nostdin = false;
@@ -312,12 +320,14 @@ static bool noglob = false, noinit = false, nostdin = false;
 /* stolen from scwm.c */
 static sigjmp_buf envHandleEventsLoop;
 
+
 static void segv(int ignored)
 {
   siglongjmp(envHandleEventsLoop, 1);
 }
 #endif
 
+
 static jmp_buf top_level_jump;
 void top_level_catch(int ignore);
 void top_level_catch(int ignore)
@@ -337,10 +347,7 @@ void snd_doit(int argc, char **argv)
   ss->sgx = (state_context *)calloc(1, sizeof(state_context));
   ss->sgx->axis_color_set = false;
 
-#if HAVE_GUILE
-  XEN_EVAL_C_STRING("(set! scm-repl-prompt \"snd> \")");
-#endif
-#if HAVE_S7
+#if HAVE_SCHEME
   xen_s7_set_repl_prompt("snd>");
 #endif
 
@@ -430,11 +437,6 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("(define (" S_graph_data " . args) #f)");
 
   XEN_EVAL_C_STRING("(define (" S_in " . args) #f)"); 
-  /* Guile: XEN_EVAL_C_STRING("(define (in time thunk) (join-thread (call-with-new-thread (lambda () (usleep (* 1000 time)) (thunk)))))"); */
-  /* 
-   * but this requires a join somewhere, which makes it kinda pointless
-   * and select on SIGALRM is too tricky
-   */
   XEN_EVAL_C_STRING("(define (" S_main_widgets " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_make_color " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_make_graph_data " . args) #f)");
@@ -468,6 +470,9 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("(define (" S_colormap_ref " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_colormap_name " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_add_colormap " . args) #f)");
+
+  XEN_EVAL_C_STRING("(define " S_x_bounds " (make-procedure-with-setter (lambda args #f) (lambda args #f)))");
+  XEN_EVAL_C_STRING("(define " S_y_bounds " (make-procedure-with-setter (lambda args #f) (lambda args #f)))");
 #endif
 
 #if HAVE_RUBY
@@ -600,6 +605,11 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("Selection_context = 2");
   XEN_EVAL_C_STRING("Time_graph = 0");
   XEN_EVAL_C_STRING("Transform_graph = 1");
+
+  XEN_EVAL_C_STRING("def x_bounds (s, c, a) false end");
+  XEN_EVAL_C_STRING("def set_x_bounds (s, c, ax, a) false end");
+  XEN_EVAL_C_STRING("def y_bounds (s, c, a) false end");
+  XEN_EVAL_C_STRING("def set_y_bounds (s, c, ax, a) false end");
 #endif
 
 #if HAVE_FORTH
@@ -680,6 +690,10 @@ void snd_doit(int argc, char **argv)
 : " S_zoom_color " #f ;\n\
 : set-" S_zoom_color " { a } #f ;\n\
 : " S_axis_info " { s c a } #f ;\n\
+: " S_x_bounds " { s c a } #f ;\n\
+: set-" S_x_bounds " { a } #f ;\n\
+: " S_y_bounds " { s c a } #f ;\n\
+: set-" S_y_bounds " { a } #f ;\n\
 : " S_channel_widgets " { s c } #f ;\n\
 : " S_color_p " { a } #f ;\n\
 : " S_color_to_list " { a } #f ;\n\
