@@ -57,6 +57,7 @@
 #define S_channel_amp_envs              "channel-amp-envs"
 #define S_channel_data                  "channel-data"
 #define S_channel_properties            "channel-properties"
+#define S_channel_property              "channel-property"
 #define S_channel_style                 "channel-style"
 #define S_channel_to_vct                "channel->vct"
 #define S_channel_widgets               "channel-widgets"
@@ -156,6 +157,7 @@
 #define S_edit_list_to_function         "edit-list->function"
 #define S_edit_position                 "edit-position"
 #define S_edit_properties               "edit-properties"
+#define S_edit_property                 "edit-property"
 #define S_edit_tree                     "edit-tree"
 #define S_edits                         "edits"
 #define S_env_channel                   "env-channel"
@@ -317,6 +319,7 @@
 #define S_mark_hook                     "mark-hook"
 #define S_mark_name                     "mark-name"
 #define S_mark_properties               "mark-properties"
+#define S_mark_property                 "mark-property"
 #define S_mark_p                        "mark?"
 #define S_mark_sample                   "mark-sample"
 #define S_mark_sync                     "mark-sync"
@@ -347,6 +350,7 @@
 #define S_mix_name                      "mix-name"
 #define S_mix_position                  "mix-position"
 #define S_mix_properties                "mix-properties"
+#define S_mix_property                  "mix-property"
 #define S_mix_region                    "mix-region"
 #define S_mix_release_hook              "mix-release-hook"
 #define S_mix_sampler_p                 "mix-sampler?"
@@ -372,7 +376,6 @@
 #define S_mouse_leave_listener_hook     "mouse-leave-listener-hook"
 #define S_mouse_leave_text_hook         "mouse-leave-text-hook"
 #define S_mouse_press_hook              "mouse-press-hook"
-#define S_mus_audio_describe            "mus-audio-describe"
 #define S_mus_error_hook                "mus-error-hook"
 #define S_name_click_hook               "name-click-hook"
 #define S_new_sound                     "new-sound"
@@ -396,8 +399,8 @@
 #define S_output_name_hook              "output-name-hook"
 #define S_pad_channel                   "pad-channel"
 #define S_pausing                       "pausing"
+#define S_peak_env_dir                  "peak-env-dir"
 #define S_peak_env_hook                 "peak-env-hook"
-#define S_peak_env_info                 "peak-env-info"
 #define S_peaks                         "peaks"
 #define S_peaks_font                    "peaks-font"
 #define S_play                          "play"
@@ -423,7 +426,6 @@
 #define S_read_hook                     "read-hook"
 #define S_read_mix_sample               "read-mix-sample"
 #define S_read_only                     "read-only"
-#define S_read_peak_env_info_file       "read-peak-env-info-file"
 #define S_read_region_sample            "read-region-sample"
 #define S_read_sample                   "read-sample"
 #define S_recorder_dialog               "recorder-dialog"
@@ -576,6 +578,7 @@
 #define S_sound_loop_info               "sound-loop-info"
 #define S_sound_p                       "sound?"
 #define S_sound_properties              "sound-properties"
+#define S_sound_property                "sound-property"
 #define S_sound_widgets                 "sound-widgets"
 #define S_sound_to_integer              "sound->integer"
 #define S_soundfont_info                "soundfont-info"
@@ -677,11 +680,12 @@
 #define S_with_background_processes     "with-background-processes"
 #define S_with_file_monitor             "with-file-monitor"
 #define S_with_gl                       "with-gl"
+#define S_with_inset_graph              "with-inset-graph"
 #define S_with_mix_tags                 "with-mix-tags"
+#define S_with_pointer_focus            "with-pointer-focus"
 #define S_with_relative_panes           "with-relative-panes"
 #define S_with_tracking_cursor          "with-tracking-cursor"
 #define S_with_verbose_cursor           "with-verbose-cursor"
-#define S_write_peak_env_info_file      "write-peak-env-info-file"
 #define S_x_axis_as_clock               "x-axis-as-clock"
 #define S_x_axis_as_percentage          "x-axis-as-percentage"
 #define S_x_axis_in_beats               "x-axis-in-beats"
