@@ -901,6 +901,9 @@ static XEN mouse_leave_text_hook;
 
 void mouse_enter_text_callback(Widget w, XtPointer context, XEvent *event, Boolean *flag)
 {
+  if (with_pointer_focus(ss))
+    goto_window(w);
+
   if (XEN_HOOKED(mouse_enter_text_hook))
     run_hook(mouse_enter_text_hook,
 	     XEN_LIST_1(XEN_WRAP_WIDGET(w)),
@@ -1024,8 +1027,7 @@ void listener_append_and_prompt(const char *msg)
 
 static void listener_return_callback(Widget w, XtPointer context, XtPointer info)
 {
-  if (!(ss->error_lock))
-    listener_return(w, find_prompt(w, XmTextGetInsertionPosition(w)));
+  listener_return(w, find_prompt(w, XmTextGetInsertionPosition(w)));
   /* prompt loc (last prompt pos) used only by read hook */
 }
 
@@ -1126,7 +1128,7 @@ static void listener_modify_callback(Widget w, XtPointer context, XtPointer info
       (XtIsManaged(completions_pane)))
     XtUnmanageChild(completions_pane);
 
-#if HAVE_S7
+#if HAVE_SCHEME
   if (cbs->text->length == 1)
     ss->listener_char = cbs->text->ptr[0];
 #endif
@@ -1152,6 +1154,9 @@ static XEN mouse_leave_listener_hook;
 
 static void listener_focus_callback(Widget w, XtPointer context, XEvent *event, Boolean *flag)
 {
+  if (with_pointer_focus(ss))
+    goto_window(listener_text);
+
   if (XEN_HOOKED(mouse_enter_listener_hook))
     run_hook(mouse_enter_listener_hook,
 	     XEN_LIST_1(XEN_WRAP_WIDGET(listener_text)), /* not w */
