@@ -4,7 +4,6 @@
 #include <stddef.h>
 #include <math.h>
 #include <stdio.h>
-#include <errno.h>
 #include <stdlib.h>
 #include <fcntl.h>
 #include <string.h>
@@ -55,6 +54,7 @@ int add_name(char *name, char *hdr)
   if ((isdigit(name[0])) || (strlen(name) == 1)) return(-1);
 
   if (isupper(name[0])) return(-1);
+
   if ((strcmp(hdr, "snd-nogui0.h") == 0) ||
       (strcmp(hdr, "snd-nogui1.h") == 0))
     nnames[nname_ctr++] = name;
@@ -194,7 +194,7 @@ static int greater_compare(const void *a, const void *b)
 
 int main(int argc, char **argv)
 {
-  int i, j, fd, curfile, chars, k, in_comment = 0, in_white = 0, calls = 0, in_parens = 0, in_quotes = 0, in_define = 0, in_curly = 0;
+  int i, j, fd, curfile, chars, k, in_comment = 0, in_white = 0, calls = 0, in_parens = 0, in_quotes = 0, in_define = 0, in_curly = 0, in_enum = 0;
   int maxc[NAME_SIZE], maxf[NAME_SIZE], maxg[NAME_SIZE], mcalls[NAME_SIZE];
   qdata **qs;
   char input[MAX_CHARS];
@@ -255,7 +255,6 @@ int main(int argc, char **argv)
   add_file("vct.c");
   add_file("sndlib2xen.c");
   add_file("clm2xen.c");
-  add_file("midi.c");
   add_file("snd-io.c");
   add_file("snd-utils.c");
   add_file("snd-error.c");
@@ -335,7 +334,6 @@ int main(int argc, char **argv)
   add_file("xg.c");
 
   add_file("cmus.c");
-  add_file("sc.c");
   add_file("ffi.lisp");
   add_file("sndlib2clm.lisp");
   add_file("run.lisp");
@@ -358,7 +356,6 @@ int main(int argc, char **argv)
 	  do 
 	    {
 	      chars = read(fd, input, MAX_CHARS);
-	      /* fprintf(stderr,"%s %d ", headers[i], chars); */
 	      for (j = 0; j < chars; j++)
 		{
 		  if ((in_comment == 0) && (in_curly == 0))
@@ -405,7 +402,7 @@ int main(int argc, char **argv)
 				    }
 				}
 			    }
-			  /* else if (k > 0) fprintf(stderr,"drop %s %d %d\n",curname,in_parens, in_quotes); */
+			  /* else if (k > 0) fprintf(stderr,"drop %s %d %d\n",curname, in_parens, in_quotes); */
 			  k = 0;
 			  if ((input[j] == '/') && (input[j + 1] == '*'))
 			    in_comment = 1;
@@ -466,6 +463,7 @@ int main(int argc, char **argv)
       in_comment = 0;
       in_white = 0;
       in_define = 0;
+      in_enum = 0;
       for (i = 0; i < files_ctr; i++)
 	{
 	  char **all_names = NULL;
@@ -507,7 +505,7 @@ int main(int argc, char **argv)
 				in_comment = 1;
 			      else
 				{
-				  if ((input[j] == '#') && (input[j + 1] == 'd'))
+				  if ((input[j] == '#') && ((input[j + 1] == 'd') || (input[j + 1] == 'u')))
 				    {
 				      in_define = 1;
 				      got_macro = false;
@@ -523,8 +521,21 @@ int main(int argc, char **argv)
 				      (j < (chars - 1)) && 
 				      ((input[j - 1] != '\'') || (input[j + 1] != '\'')))
 				    {
-				      if (input[j] == '{') curly_ctr++;
-				      else if (input[j] == '}') curly_ctr--;
+				      if (input[j] == '{') 
+					{
+					  curly_ctr++;
+					  if ((j > 4) && 
+					      (strncmp((input + (j - 5)), "enum", 4) == 0))
+					    in_enum = true;
+					}
+				      else 
+					{
+					  if (input[j] == '}') 
+					    {
+					      curly_ctr--;
+					      if (in_enum) in_enum = false;
+					    }
+					}
 				    }
 				}
 			      
@@ -553,7 +564,11 @@ int main(int argc, char **argv)
 					    all_names_counts[m]++;
 					  }
 				      
-				      if ((!got_macro) && (in_define == 1) && (strcmp(curname, "define") != 0))
+				      if (((!got_macro) && 
+					   (in_define == 1) && 
+					   (strcmp(curname, "define") != 0) &&
+					   (strcmp(curname, "undef") != 0)) ||
+					  (in_enum))
 					{
 					  got_macro = true;
 					  if (!happy)
