@@ -232,7 +232,7 @@ bool mus_vct_equalp(vct *v1, vct *v2)
 
 static XEN g_vct_fill(XEN obj, XEN val);
 
-#if (HAVE_S7)
+#if (HAVE_SCHEME)
 static XEN g_vct_ref(XEN obj, XEN pos);
 static XEN g_vct_set(XEN obj, XEN pos, XEN val);
 static XEN g_vct_length(XEN obj);
@@ -273,11 +273,11 @@ static XEN s7_mus_vct_fill(s7_scheme *sc, XEN obj, XEN val)
 
 XEN_MAKE_OBJECT_PRINT_PROCEDURE(vct, print_vct, mus_vct_to_string)
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
 static XEN equalp_vct(XEN obj1, XEN obj2)
 {
   if ((!(MUS_VCT_P(obj1))) || (!(MUS_VCT_P(obj2)))) return(XEN_FALSE);
-  return(xen_return_first(C_TO_XEN_BOOLEAN(mus_vct_equalp(XEN_TO_VCT(obj1), XEN_TO_VCT(obj2))), obj1, obj2));
+  return(C_TO_XEN_BOOLEAN(mus_vct_equalp(XEN_TO_VCT(obj1), XEN_TO_VCT(obj2))));
 }
 #endif
 
@@ -321,7 +321,7 @@ XEN xen_make_vct(mus_long_t len, mus_float_t *data)
   if ((len > 0) && 
       (data == NULL))
     XEN_ERROR(XEN_ERROR_TYPE("out-of-memory"),
-	      XEN_LIST_2(C_TO_XEN_STRING(S_make_vct),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_make_vct ": can't allocate size ~A"),
 			 C_TO_XEN_INT(len)));
 
   new_vct = (vct *)malloc(sizeof(vct));
@@ -359,7 +359,8 @@ static XEN g_make_vct(XEN len, XEN filler)
 initial-element: \n  " vct_make_example
 
   mus_long_t size;
-  XEN_ASSERT_TYPE(XEN_INT64_T_P(len), len, XEN_ONLY_ARG, S_make_vct, "an integer");
+  XEN_ASSERT_TYPE(XEN_INT64_T_P(len), len, XEN_ARG_1, S_make_vct, "an integer");
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(filler) || XEN_NOT_BOUND_P(filler), filler, XEN_ARG_2, S_make_vct, "a number");
 
   size = XEN_TO_C_INT64_T(len);
   if (size <= 0) 
@@ -482,7 +483,7 @@ static XEN g_vct_set(XEN obj, XEN pos, XEN val)
     XEN_OUT_OF_RANGE_ERROR(S_vct_setB, 2, pos, "index ~A >= vct-length?");
 
   v->data[loc] = XEN_TO_C_DOUBLE(val);
-  return(xen_return_first(val, obj, pos));
+  return(val);
 }
 
 
@@ -499,7 +500,7 @@ static XEN g_vct_multiply(XEN obj1, XEN obj2)
   v2 = XEN_TO_VCT(obj2);
   lim = MIN(v1->length, v2->length);
   for (i = 0; i < lim; i++) v1->data[i] *= v2->data[i];
-  return(xen_return_first(obj1, obj2)); /* I wonder if this is necessary */
+  return(obj1);
 }
 
 
@@ -518,17 +519,27 @@ static XEN g_vct_add(XEN obj1, XEN obj2, XEN offs)
   lim = MIN(v1->length, v2->length);
   if (XEN_INT64_T_P(offs))
     {
-      j = XEN_TO_C_INT64_T(offs); /* needed by g++ 3.2 -- otherwise segfault from the compiler! */
-      if (j < 0) XEN_OUT_OF_RANGE_ERROR(S_vct_addB, 3, offs, "offset ~A < 0?");
+      j = XEN_TO_C_INT64_T(offs);
+      if (j < 0) 
+	XEN_OUT_OF_RANGE_ERROR(S_vct_addB, 3, offs, "offset ~A < 0?");
+
       if ((j + lim) > v1->length)
 	lim = (v1->length - j);
+
       for (i = 0; i < lim; i++, j++) 
 	v1->data[j] += v2->data[i];
     }
   else
-    for (i = 0; i < lim; i++) 
-      v1->data[i] += v2->data[i];
-  return(xen_return_first(obj1, obj2));
+    {
+      mus_float_t *d1, *d2, *dend;
+      d1 = v1->data;
+      d2 = v2->data;
+      dend = (mus_float_t *)(v1->data + lim);
+      while (d1 != dend) (*d1++) += (*d2++);  /* is this safe? or perhaps use (*d1++) = (*d1) + (*d2++)? */
+
+      /* for (i = 0; i < lim; i++) v1->data[i] += v2->data[i]; */
+    }
+  return(obj1);
 }
 
 
@@ -545,7 +556,7 @@ static XEN g_vct_subtract(XEN obj1, XEN obj2)
   v2 = XEN_TO_VCT(obj2);
   lim = MIN(v1->length, v2->length);
   for (i = 0; i < lim; i++) v1->data[i] -= v2->data[i];
-  return(xen_return_first(obj1, obj2));
+  return(obj1);
 }
 
 
@@ -568,7 +579,7 @@ static XEN g_vct_scale(XEN obj1, XEN obj2)
       if (scl != 1.0)
 	for (i = 0; i < v1->length; i++) v1->data[i] *= scl;
     }
-  return(xen_return_first(obj1, obj2));
+  return(obj1);
 }
 
 
@@ -586,7 +597,7 @@ static XEN g_vct_offset(XEN obj1, XEN obj2)
   scl = XEN_TO_C_DOUBLE(obj2);
   if (scl != 0.0)
     for (i = 0; i < v1->length; i++) v1->data[i] += scl;
-  return(xen_return_first(obj1, obj2));
+  return(obj1);
 }
 
 
@@ -605,7 +616,7 @@ static XEN g_vct_fill(XEN obj1, XEN obj2)
   if (scl == 0.0)
     mus_clear_array(v1->data, v1->length);
   else for (i = 0; i < v1->length; i++) v1->data[i] = scl;
-  return(xen_return_first(obj1, obj2));
+  return(obj1);
 }
 
 
@@ -633,7 +644,7 @@ v. " vct_map_example " is the same as " vct_fill_example
   XEN_ASSERT_TYPE(MUS_VCT_P(obj), obj, XEN_ARG_1, S_vct_mapB, "a vct");
 
   v = XEN_TO_VCT(obj);
-#if HAVE_S7 && USE_SND
+#if HAVE_SCHEME && USE_SND
   {
     struct ptree *pt = NULL;
     if ((optimization(ss)) > 0)
@@ -644,7 +655,7 @@ v. " vct_map_example " is the same as " vct_fill_example
 	    for (i = 0; i < v->length; i++) 
 	      v->data[i] = mus_run_evaluate_ptree_0f2f(pt);
 	    mus_run_free_ptree(pt);
-	    return(xen_return_first(obj, proc));
+	    return(obj);
 	  }
       }
 
@@ -658,28 +669,33 @@ v. " vct_map_example " is the same as " vct_fill_example
     v->data[i] = XEN_TO_C_DOUBLE(XEN_CALL_0_NO_CATCH(proc));
 #endif
 
-  return(xen_return_first(obj, proc));
+  return(obj);
+}
+
+
+double mus_vct_peak(vct *v)
+{
+  mus_float_t val = 0.0, absv;
+  mus_float_t *d1, *dend;
+
+  val = fabs(v->data[0]);
+  d1 = (mus_float_t *)(v->data + 1);
+  dend = (mus_float_t *)(v->data + v->length);
+  while (d1 != dend)
+    {
+      absv = fabs(*d1++);
+      if (absv > val) val = absv;
+    }
+
+  return(val);
 }
 
 
 XEN g_vct_peak(XEN obj)
 {
   #define H_vct_peak "(" S_vct_peak " v): max of abs of elements of v"
-  mus_long_t i;
-  mus_float_t val = 0.0, absv;
-  vct *v;
-
   XEN_ASSERT_TYPE(MUS_VCT_P(obj), obj, XEN_ONLY_ARG, S_vct_peak, "a vct");
-
-  v = XEN_TO_VCT(obj);
-  val = fabs(v->data[0]); 
-  for (i = 1; i < v->length; i++) 
-    {
-      absv = fabs(v->data[i]); 
-      if (absv > val) val = absv;
-    }
-
-  return(xen_return_first(C_TO_XEN_DOUBLE(val), obj));
+  return(C_TO_XEN_DOUBLE(mus_vct_peak(XEN_TO_VCT(obj))));
 }
 
 
@@ -724,7 +740,7 @@ static XEN g_vct_subseq(XEN vobj, XEN start, XEN end, XEN newv)
   for (i = istart, j = 0; (j < new_len) && (i < old_len); i++, j++)
     vnew->data[j] = vold->data[i];
 
-  return(xen_return_first(res, vobj, vnew));
+  return(res);
 }
 
 
@@ -739,12 +755,17 @@ XEN xen_list_to_vct(XEN lst)
 
   if (len == 0) 
     return(XEN_FALSE);
+
   scv = xen_make_vct(len, (mus_float_t *)calloc(len, sizeof(mus_float_t)));
   v = XEN_TO_VCT(scv);
   for (i = 0, lst1 = XEN_COPY_ARG(lst); i < len; i++, lst1 = XEN_CDR(lst1)) 
-    v->data[i] = (mus_float_t)XEN_TO_C_DOUBLE_OR_ELSE(XEN_CAR(lst1), 0.0);
+    {
+      if (XEN_NUMBER_P(XEN_CAR(lst1)))
+	v->data[i] = (mus_float_t)XEN_TO_C_DOUBLE_OR_ELSE(XEN_CAR(lst1), 0.0);
+      else XEN_WRONG_TYPE_ARG_ERROR(S_list_to_vct, i, XEN_CAR(lst1), "a number");
+    }
 
-  return(xen_return_first(scv, lst));
+  return(scv);
 }
 
 
@@ -771,7 +792,7 @@ static XEN g_vct_to_list(XEN vobj)
   vct *v;
   XEN_ASSERT_TYPE(MUS_VCT_P(vobj), vobj, XEN_ONLY_ARG, S_vct_to_list, "a vct");
   v = XEN_TO_VCT(vobj);
-  return(xen_return_first(mus_array_to_list(v->data, 0, v->length), vobj));
+  return(mus_array_to_list(v->data, 0, v->length));
 }
 
 
@@ -781,7 +802,7 @@ static XEN g_vector_to_vct(XEN vect)
   mus_long_t len, i;
   vct *v;
   XEN scv;
-#if HAVE_S7
+#if HAVE_SCHEME
   int gc_loc;
 #endif
 
@@ -790,7 +811,7 @@ static XEN g_vector_to_vct(XEN vect)
   len = (mus_long_t)XEN_VECTOR_LENGTH(vect);
   if (len == 0) return(XEN_FALSE);
   scv = xen_make_vct(len, (mus_float_t *)calloc(len, sizeof(mus_float_t)));
-#if HAVE_S7
+#if HAVE_SCHEME
   gc_loc = s7_gc_protect(s7, scv);
 #endif
 
@@ -798,10 +819,10 @@ static XEN g_vector_to_vct(XEN vect)
   for (i = 0; i < len; i++) 
     v->data[i] = (mus_float_t)XEN_TO_C_DOUBLE(XEN_VECTOR_REF(vect, i));
 
-#if HAVE_S7
+#if HAVE_SCHEME
   s7_gc_unprotect_at(s7, gc_loc);
 #endif
-  return(xen_return_first(scv, vect));
+  return(scv);
 }
 
 
@@ -811,7 +832,7 @@ static XEN g_vct_to_vector(XEN vobj)
   vct *v;
   mus_long_t i, len;
   XEN new_vect;
-#if HAVE_S7
+#if HAVE_SCHEME
   int gc_loc;
 #endif
 
@@ -821,7 +842,7 @@ static XEN g_vct_to_vector(XEN vobj)
   len = v->length;
   new_vect = XEN_MAKE_VECTOR(len, C_TO_XEN_DOUBLE(0.0));
 
-#if HAVE_S7
+#if HAVE_SCHEME
   gc_loc = s7_gc_protect(s7, new_vect);
 #endif
 #if HAVE_RUBY && HAVE_RB_GC_DISABLE
@@ -835,14 +856,14 @@ static XEN g_vct_to_vector(XEN vobj)
   for (i = 0; i < len; i++) 
     XEN_VECTOR_SET(new_vect, i, C_TO_XEN_DOUBLE(v->data[i]));
 
-#if HAVE_S7
+#if HAVE_SCHEME
   s7_gc_unprotect_at(s7, gc_loc);
 #endif
 #if HAVE_RUBY && HAVE_RB_GC_DISABLE
   rb_gc_enable();
 #endif
 
-  return(xen_return_first(new_vect, vobj));
+  return(new_vect);
 }
 
 
@@ -1202,14 +1223,10 @@ vct( 0.5 0.3 0.1 ) .g => #<vct[len=3]: 0.500 0.300 0.100>"
 #endif
 
 
-#if WITH_MODULES
-static void mus_vct_init_1(void *ignore)
-#else
 void mus_vct_init(void)
-#endif
 {
 
-#if HAVE_S7
+#if HAVE_SCHEME
   vct_tag = XEN_MAKE_OBJECT_TYPE("<vct>", print_vct, free_vct, s7_mus_vct_equalp, NULL, 
 				 s7_mus_vct_apply, s7_mus_vct_set, s7_mus_vct_length, 
 				 s7_mus_vct_copy, s7_mus_vct_fill);
@@ -1217,15 +1234,6 @@ void mus_vct_init(void)
   vct_tag = XEN_MAKE_OBJECT_TYPE("Vct", sizeof(vct));
 #endif
 
-#if HAVE_GUILE
-  scm_set_smob_print(vct_tag, print_vct);
-  scm_set_smob_free(vct_tag, free_vct);
-  scm_set_smob_equalp(vct_tag, equalp_vct);
-#if HAVE_APPLICABLE_SMOB
-  scm_set_smob_apply(vct_tag, XEN_PROCEDURE_CAST g_vct_ref, 1, 0, 0);
-#endif
-#endif
-
 #if HAVE_FORTH
   fth_set_object_inspect(vct_tag,   print_vct);
   fth_set_object_dump(vct_tag,      g_vct_to_readable_string);
@@ -1292,23 +1300,18 @@ void mus_vct_init(void)
   XEN_DEFINE_PROCEDURE(S_vector_to_vct,     g_vector_to_vct_w, 1, 0, 0, H_vector_to_vct);
   XEN_DEFINE_PROCEDURE(S_vct_to_vector,     g_vct_to_vector_w, 1, 0, 0, H_vct_to_vector);
   XEN_DEFINE_PROCEDURE(S_vct_length,        g_vct_length_w,    1, 0, 0, H_vct_length);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_multiplyB, g_vct_multiply_w,  2, 0, 0, H_vct_multiplyB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_scaleB,    g_vct_scale_w,     2, 0, 0, H_vct_scaleB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_fillB,     g_vct_fill_w,      2, 0, 0, H_vct_fillB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_addB,      g_vct_add_w,       2, 1, 0, H_vct_addB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_subtractB, g_vct_subtract_w,  2, 0, 0, H_vct_subtractB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_offsetB,   g_vct_offset_w,    2, 0, 0, H_vct_offsetB);
+  XEN_DEFINE_PROCEDURE(S_vct_multiplyB,     g_vct_multiply_w,  2, 0, 0, H_vct_multiplyB);
+  XEN_DEFINE_PROCEDURE(S_vct_scaleB,        g_vct_scale_w,     2, 0, 0, H_vct_scaleB);
+  XEN_DEFINE_PROCEDURE(S_vct_fillB,         g_vct_fill_w,      2, 0, 0, H_vct_fillB);
+  XEN_DEFINE_PROCEDURE(S_vct_addB,          g_vct_add_w,       2, 1, 0, H_vct_addB);
+  XEN_DEFINE_PROCEDURE(S_vct_subtractB,     g_vct_subtract_w,  2, 0, 0, H_vct_subtractB);
+  XEN_DEFINE_PROCEDURE(S_vct_offsetB,       g_vct_offset_w,    2, 0, 0, H_vct_offsetB);
   XEN_DEFINE_PROCEDURE(S_vct_peak,          g_vct_peak_w,      1, 0, 0, H_vct_peak);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_moveB,     g_vct_move_w,      3, 1, 0, H_vct_moveB);
+  XEN_DEFINE_PROCEDURE(S_vct_moveB,         g_vct_move_w,      3, 1, 0, H_vct_moveB);
   XEN_DEFINE_PROCEDURE(S_vct_subseq,        g_vct_subseq_w,    2, 2, 0, H_vct_subseq);
   XEN_DEFINE_PROCEDURE(S_vct,               g_vct_w,           0, 0, 1, H_vct);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_reverse,   g_vct_reverse_w,   1, 1, 0, H_vct_reverse);
-
-#if HAVE_S7 && USE_SND
-  XEN_DEFINE_SET_PROCEDURE(S_vct_mapB,      g_vct_mapB_w,      2, 0, 0, H_vct_mapB);
-#else
+  XEN_DEFINE_PROCEDURE(S_vct_reverse,       g_vct_reverse_w,   1, 1, 0, H_vct_reverse);
   XEN_DEFINE_PROCEDURE(S_vct_mapB,          g_vct_mapB_w,      2, 0, 0, H_vct_mapB);
-#endif
 
 #if HAVE_SCHEME || HAVE_FORTH
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_vct_ref, g_vct_ref_w, H_vct_ref, "set-" S_vct_ref, g_vct_set_w,  2, 0, 3, 0);
@@ -1317,45 +1320,7 @@ void mus_vct_init(void)
 #endif
 
   XEN_DEFINE_PROCEDURE(S_vct_to_string,     g_vct_to_readable_string_w, 1, 0, 0, H_vct_to_string);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_setB,      g_vct_set_w,       3, 0, 0, H_vct_setB);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_times,     g_vct_times_w,     2, 0, 0, H_vct_times);
-  XEN_DEFINE_SET_PROCEDURE(S_vct_plus,      g_vct_plus_w,      2, 0, 0, H_vct_plus);
-
-#if WITH_MODULES
-  scm_c_export(S_make_vct,
-	       S_vct_copy,
-	       S_vct_p,
-	       S_list_to_vct,
-	       S_vct_to_list,
-	       S_vector_to_vct,
-	       S_vct_to_vector,
-	       S_vct_length,
-	       S_vct_multiplyB,
-	       S_vct_scaleB,
-	       S_vct_fillB,
-	       S_vct_addB,
-	       S_vct_subtractB,
-	       S_vct_offsetB,
-	       S_vct_peak,
-	       S_vct_moveB,
-	       S_vct_subseq,
-	       S_vct,
-	       S_vct_mapB,
-	       S_vct_ref,
-	       S_vct_setB,
-	       S_vct_reverse,
-	       S_vct_to_string,
-	       S_vct_times,
-	       S_vct_plus,
-	       NULL);
-#endif
+  XEN_DEFINE_PROCEDURE(S_vct_setB,          g_vct_set_w,       3, 0, 0, H_vct_setB);
+  XEN_DEFINE_PROCEDURE(S_vct_times,         g_vct_times_w,     2, 0, 0, H_vct_times);
+  XEN_DEFINE_PROCEDURE(S_vct_plus,          g_vct_plus_w,      2, 0, 0, H_vct_plus);
 }
-
-
-#if WITH_MODULES
-void mus_vct_init(void)
-{
-  scm_c_define_module("snd sndlib", mus_vct_init_1, NULL);
-}
-#endif
-
